@@ -30,9 +30,8 @@ class Skipped extends Pattern
   public int matchInternal(int pos, Pthings pt)
   {
     // if(pt.no_check || s.regionMatches(pt.ignoreCase,0,pt.src,pos,s.length()))
-    if (pt.no_check
-            || CaseMgr.regionMatches(s, pt.ignoreCase, 0, pt.src, pos,
-                    s.length()))
+    if (pt.no_check || CaseMgr.regionMatches(s, pt.ignoreCase, 0, pt.src,
+            pos, s.length()))
     {
       return nextMatch(pos + s.length(), pt);
     }
