@@ -32,9 +32,6 @@
  */
 package ext.edu.ucsf.rbvi.strucviz2;
 
-import jalview.bin.Cache;
-import jalview.gui.Preferences;
-
 import java.io.File;
 import java.io.IOException;
 import java.util.ArrayList;
@@ -42,6 +39,7 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
@@ -49,6 +47,9 @@ import java.util.Set;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import jalview.bin.Cache;
+import jalview.gui.Preferences;
+
 /**
  * This object maintains the relationship between Chimera objects and Cytoscape
  * objects.
@@ -56,6 +57,29 @@ import org.slf4j.LoggerFactory;
 
 public class StructureManager
 {
+  /*
+   * Version numbers to build Windows installation paths for 
+   * Chimera  https://www.cgl.ucsf.edu/chimera/download.html
+   * ChimeraX http://www.rbvi.ucsf.edu/chimerax/download.html#release
+   *          https://www.rbvi.ucsf.edu/trac/ChimeraX/wiki/ChangeLog
+   * These are a fallback for Jalview users who don't save path in Preferences;
+   * these will need to be updated as new versions are released;
+   * deliberately not 'final' (so modifiable using Groovy).
+   * 
+   * May 2020: 1.14 is Chimera latest, anticipating a few more...
+   * 0.93 is ChimeraX latest, 1.0 expected soon
+   */
+  private static String[] CHIMERA_VERSIONS = new String[] { "1.18",
+      "1.17.4", "1.17.3", "1.17.2", "1.17.1", "1.17", "1.16.2", "1.16.1",
+      "1.16", "1.15.2", "1.15.1", "1.15", "1.14.2", "1.14.1", "1.14",
+      "1.13.1", "1.13", "1.12.2", "1.12.1", "1.12", "1.11.2", "1.11.2",
+      "1.11.1", "1.11" };
+
+  // Missing 1.1 as this has known bug see JAL-2422
+  private static String[] CHIMERAX_VERSIONS = new String[] { "1.7", "1.6.1",
+      "1.6", "1.5", "1.4", "1.3", "1.2.5", "1.0", "0.93", "0.92", "0.91",
+      "0.9" };
+
   static final String[] defaultStructureKeys = { "Structure", "pdb",
       "pdbFileName", "PDB ID", "structure", "biopax.xref.PDB", "pdb_ids",
       "ModelName", "ModelNumber" };
@@ -896,7 +920,7 @@ public class StructureManager
   StructureSettings defaultSettings = null;
 
   // TODO: [Optional] Change priority of Chimera paths
-  public static List<String> getChimeraPaths()
+  public static List<String> getChimeraPaths(boolean isChimeraX)
   {
     List<String> pathList = new ArrayList<>();
 
@@ -915,42 +939,125 @@ public class StructureManager
     // }
     // }
 
+    String os = System.getProperty("os.name");
+    String userPath = Cache
+            .getDefault(isChimeraX ? Preferences.CHIMERAX_PATH
+                    : Preferences.CHIMERA_PATH, null);
+
     /*
-     * Jalview addition: check if path set in user preferences.
+     * paths are based on getChimeraPaths() in
+     * Chimera:
+     * https://github.com/RBVI/structureViz2/blob/master/src/main/java/edu/ucsf/rbvi/structureViz2/internal/model/StructureManager.java
+     * ChimeraX:
+     * https://github.com/RBVI/structureVizX/blob/master/src/main/java/edu/ucsf/rbvi/structureVizX/internal/model/StructureManager.java
+     */
+    String chimera = isChimeraX ? "ChimeraX" : "Chimera";
+    String chimeraExe = isChimeraX ? "ChimeraX" : "chimera";
+
+    /*
+     * Jalview addition: check if path set in user preferences
      */
-    String userPath = Cache.getDefault(Preferences.CHIMERA_PATH, null);
     if (userPath != null)
     {
-      pathList.add(0, userPath);
+      // in macos, deal with the user selecting the .app folder
+      boolean adjusted = false;
+      if (os.startsWith("Mac") && userPath.endsWith((".app")))
+      {
+        String possiblePath = String.format("%s/Contents/MacOS/%s",
+                userPath, chimeraExe);
+        if (new File(possiblePath).exists())
+        {
+          pathList.add(possiblePath);
+          adjusted = true;
+        }
+      }
+      if (!adjusted)
+      {
+        pathList.add(userPath);
+      }
     }
 
     // Add default installation paths
-    String os = System.getProperty("os.name");
     if (os.startsWith("Linux"))
     {
-      pathList.add("/usr/local/chimera/bin/chimera");
-      pathList.add("/usr/local/bin/chimera");
-      pathList.add("/usr/bin/chimera");
-      pathList.add(System.getProperty("user.home") + "/opt/bin/chimera");
+      // ChimeraX .deb and .rpm packages put symbolic link from
+      // /usr/bin/chimerax
+      pathList.add(String.format("/usr/bin/%s",
+              chimeraExe.toLowerCase(Locale.ROOT)));
+      pathList.add(String.format("/usr/bin/%s", chimeraExe));
+
+      pathList.add(String.format("/usr/local/bin/%s",
+              chimeraExe.toLowerCase(Locale.ROOT)));
+      pathList.add(String.format("/usr/local/bin/%s", chimeraExe));
+
+      // these paths also used by .deb and .rpm
+      pathList.add(String.format("/usr/lib/ucsf-%s/bin/%s",
+              chimera.toLowerCase(Locale.ROOT), chimeraExe));
+      pathList.add(String.format("/usr/libexec/UCSF-%s/bin/%s", chimera,
+              chimeraExe));
+
+      pathList.add(String.format("/usr/local/chimera/bin/%s", chimeraExe));
+
+      // user home paths
+      pathList.add(
+              String.format("%s/bin/%s", System.getProperty("user.home"),
+                      chimeraExe.toLowerCase(Locale.ROOT)));
+      pathList.add(String.format("%s/bin/%s",
+              System.getProperty("user.home"), chimeraExe));
+      pathList.add(String.format("%s/opt/bin/%s",
+              System.getProperty("user.home"),
+              chimeraExe.toLowerCase(Locale.ROOT)));
+      pathList.add(String.format("%s/opt/bin/%s",
+              System.getProperty("user.home"), chimeraExe));
+      pathList.add(String.format("%s/local/bin/%s",
+              System.getProperty("user.home"),
+              chimeraExe.toLowerCase(Locale.ROOT)));
+      pathList.add(String.format("%s/local/bin/%s",
+              System.getProperty("user.home"), chimeraExe));
     }
     else if (os.startsWith("Windows"))
     {
       for (String root : new String[] { "\\Program Files",
           "C:\\Program Files", "\\Program Files (x86)",
-          "C:\\Program Files (x86)" })
+          "C:\\Program Files (x86)", String.format("%s\\AppData\\Local",
+                  System.getProperty("user.home")) })
       {
-        for (String version : new String[] { "1.11", "1.11.1", "1.11.2",
-            "1.12", "1.12.1", "1.12.2", "1.13" })
+        String[] candidates = isChimeraX ? CHIMERAX_VERSIONS
+                : CHIMERA_VERSIONS;
+        for (String version : candidates)
         {
-          pathList.add(root + "\\Chimera " + version + "\\bin\\chimera");
-          pathList.add(
-                  root + "\\Chimera " + version + "\\bin\\chimera.exe");
+          // TODO original code doesn't include version in path; which is right?
+          String path = String.format("%s\\%s %s\\bin\\%s", root, chimera,
+                  version, chimeraExe);
+          pathList.add(path);
+          pathList.add(path + ".exe");
         }
+        // try without a version number too
+        String path = String.format("%s\\%s\\bin\\%s", root, chimera,
+                chimeraExe);
+        pathList.add(path);
+        pathList.add(path + ".exe");
       }
     }
     else if (os.startsWith("Mac"))
     {
-      pathList.add("/Applications/Chimera.app/Contents/MacOS/chimera");
+      // check for installations with version numbers first
+      String[] candidates = isChimeraX ? CHIMERAX_VERSIONS
+              : CHIMERA_VERSIONS;
+      for (String version : candidates)
+      {
+        pathList.add(
+                String.format("/Applications/%s-%s.app/Contents/MacOS/%s",
+                        chimera, version, chimeraExe));
+        pathList.add(
+                String.format("%s/Applications/%s-%s.app/Contents/MacOS/%s",
+                        System.getProperty("user.home"), chimera, version,
+                        chimeraExe));
+      }
+      pathList.add(String.format("/Applications/%s.app/Contents/MacOS/%s",
+              chimera, chimeraExe));
+      pathList.add(String.format("%s/Applications/%s.app/Contents/MacOS/%s",
+              System.getProperty("user.home"), chimera, chimeraExe));
     }
     return pathList;
   }
