@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -104,8 +104,6 @@ public class SimilarityParams implements SimilarityParamsI
 
   private boolean denominateByShortestLength;
 
-  private String secondaryStructureSource;
-
   /**
    * Constructor
    * 
@@ -202,16 +200,4 @@ public class SimilarityParams implements SimilarityParamsI
     }
     return true;
   }
-
-  @Override
-  public String getSecondaryStructureSource()
-  {
-    return secondaryStructureSource;
-  }
-
-  @Override
-  public void setSecondaryStructureSource(String secondaryStructureSource)
-  {
-    this.secondaryStructureSource = secondaryStructureSource;
-  }
 }
