@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -29,6 +29,7 @@ import java.lang.invoke.MethodHandles;
 import java.net.HttpURLConnection;
 import java.net.MalformedURLException;
 import java.net.URL;
+import java.net.URLConnection;
 import java.net.URLEncoder;
 import java.nio.charset.StandardCharsets;
 import java.util.AbstractMap;
@@ -44,7 +45,6 @@ import jalview.bin.Cache;
 import jalview.bin.Console;
 import jalview.util.ChannelProperties;
 import jalview.util.HttpUtils;
-import jalview.util.UserAgent;
 
 public class Plausible
 {
@@ -92,15 +92,15 @@ public class Plausible
     {
       defaultProps.put("install4j_version", val);
     }
-    val = System.getProperty("installer.template_version");
+    val = System.getProperty("installer_template_version");
     if (val != null)
     {
       defaultProps.put("install4j_template_version", val);
     }
-    val = System.getProperty("launcher.version");
+    val = System.getProperty("launcher_version");
     if (val != null)
     {
-      defaultProps.put("launcher.version", val);
+      defaultProps.put("launcher_version", val);
     }
     defaultProps.put("java_arch",
             System.getProperty("os.arch") + " "
@@ -122,7 +122,7 @@ public class Plausible
     // random clientId to make User-Agent unique (to register analytic)
     clientId = String.format("%08x", new Random().nextInt());
 
-    USER_AGENT = UserAgent.getUserAgent(
+    USER_AGENT = HttpUtils.getUserAgent(
             MethodHandles.lookup().lookupClass().getCanonicalName() + " "
                     + clientId);
   }
@@ -213,8 +213,8 @@ public class Plausible
     try
     {
       URL url = new URL(urlSb.toString());
-      HttpURLConnection httpURLConnection = (HttpURLConnection) HttpUtils
-              .openConnection(url);
+      URLConnection urlConnection = url.openConnection();
+      HttpURLConnection httpURLConnection = (HttpURLConnection) urlConnection;
       httpURLConnection.setRequestMethod("POST");
       httpURLConnection.setDoOutput(true);
 
@@ -553,8 +553,8 @@ public class Plausible
     try
     {
       URL url = new URL(CONFIG_API_BASE_URL);
-      HttpURLConnection httpURLConnection = (HttpURLConnection) HttpUtils
-              .openConnection(url);
+      URLConnection urlConnection = url.openConnection();
+      HttpURLConnection httpURLConnection = (HttpURLConnection) urlConnection;
       httpURLConnection.setRequestMethod("GET");
       httpURLConnection.setRequestProperty("User-Agent", USER_AGENT);
       httpURLConnection.setConnectTimeout(5000);
