@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -145,7 +145,7 @@ public class RotatableCanvas extends Panel implements MouseListener,
 
     scale = findScale();
 
-    // jalview.bin.Console.outPrintln("Scale factor = " + scale);
+    // System.out.println("Scale factor = " + scale);
 
     addMouseListener(this);
     addKeyListener(this);
@@ -301,7 +301,7 @@ public class RotatableCanvas extends Panel implements MouseListener,
 
         scale = findScale();
 
-        // jalview.bin.Console.outPrintln("New scale = " + scale);
+        // System.out.println("New scale = " + scale);
         img = createImage(getSize().width, getSize().height);
         ig = img.getGraphics();
 
@@ -427,7 +427,7 @@ public class RotatableCanvas extends Panel implements MouseListener,
     }
     else if (evt.getKeyChar() == 's')
     {
-      jalview.bin.Console.errPrintln("DEBUG: Rectangle selection"); // log.debug
+      System.err.println("DEBUG: Rectangle selection"); // log.debug
       if (rectx2 != -1 && recty2 != -1)
       {
         rectSelect(rectx1, recty1, rectx2, recty2);
