@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -159,7 +159,7 @@ public class HiddenSequences
 
     if (alignmentIndex < 0 || hiddenSequences[alignmentIndex] != null)
     {
-      jalview.bin.Console.outPrintln("ERROR!!!!!!!!!!!");
+      System.out.println("ERROR!!!!!!!!!!!");
       return;
     }
 
@@ -239,7 +239,7 @@ public class HiddenSequences
           }
           else
           {
-            jalview.bin.Console.outPrintln(
+            System.out.println(
                     seq.getName() + " has been deleted whilst hidden");
           }
         }
