@@ -1,3 +1,23 @@
+/*
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.1)
+ * Copyright (C) 2024 The Jalview Authors
+ * 
+ * This file is part of Jalview.
+ * 
+ * Jalview is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License 
+ * as published by the Free Software Foundation, either version 3
+ * of the License, or (at your option) any later version.
+ *  
+ * Jalview is distributed in the hope that it will be useful, but 
+ * WITHOUT ANY WARRANTY; without even the implied warranty 
+ * of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+ * PURPOSE.  See the GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with Jalview.  If not, see <http://www.gnu.org/licenses/>.
+ * The Jalview Authors are detailed in the 'AUTHORS' file.
+ */
 package jalview.datamodel;
 
 import java.awt.Color;
@@ -7,6 +27,7 @@ import java.util.List;
 
 import jalview.util.MapList;
 import jalview.ws.datamodel.alphafold.MappableContactMatrix;
+
 /**
  * Dummy contact matrix based on sequence distance
  * 
@@ -18,6 +39,7 @@ public class SeqDistanceContactMatrix
         implements ContactMatrixI
 {
   private static final String SEQUENCE_DISTANCE = "SEQUENCE_DISTANCE";
+
   private int width = 0;
 
   public SeqDistanceContactMatrix(int width)
@@ -113,11 +135,13 @@ public class SeqDistanceContactMatrix
   {
     return width;
   }
+
   @Override
-  protected double getElementAt(int _column, int i)
+  public double getElementAt(int _column, int i)
   {
     return Math.abs(_column - i);
   }
+
   @Override
   protected SeqDistanceContactMatrix newMappableContactMatrix(
           SequenceI newRefSeq, MapList newFromMapList)
