@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -157,8 +157,7 @@ public class EnsemblMap extends EnsemblRestClient
       return (parseAssemblyMappingResponse(url));
     } catch (Throwable t)
     {
-      jalview.bin.Console
-              .outPrintln("Error calling " + url + ": " + t.getMessage());
+      System.out.println("Error calling " + url + ": " + t.getMessage());
       return null;
     }
   }
@@ -266,8 +265,7 @@ public class EnsemblMap extends EnsemblRestClient
       return null;
     } catch (Throwable t)
     {
-      jalview.bin.Console
-              .outPrintln("Error calling " + url + ": " + t.getMessage());
+      System.out.println("Error calling " + url + ": " + t.getMessage());
       return null;
     }
   }
@@ -344,7 +342,7 @@ public class EnsemblMap extends EnsemblRestClient
         String ass = mapped.get("assembly_name").toString();
         if (assembly != null && !assembly.equals(ass))
         {
-          jalview.bin.Console.errPrintln(
+          System.err.println(
                   "EnsemblMap found multiple assemblies - can't resolve");
           return null;
         }
@@ -352,7 +350,7 @@ public class EnsemblMap extends EnsemblRestClient
         String chr = mapped.get("seq_region_name").toString();
         if (chromosome != null && !chromosome.equals(chr))
         {
-          jalview.bin.Console.errPrintln(
+          System.err.println(
                   "EnsemblMap found multiple chromosomes - can't resolve");
           return null;
         }
