@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -26,8 +26,6 @@ import java.awt.event.ComponentListener;
 import java.io.File;
 import java.net.URL;
 import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.StringTokenizer;
@@ -156,7 +154,7 @@ public abstract class JalviewJmolBinding extends AAStructureBindingModel
     jmolHistory(false);
     if (lastCommand == null || !lastCommand.equals(cmd))
     {
-      jmolScript(cmd + "\n", command.isWaitNeeded());
+      jmolScript(cmd + "\n");
     }
     jmolHistory(true);
     lastCommand = cmd;
@@ -165,21 +163,21 @@ public abstract class JalviewJmolBinding extends AAStructureBindingModel
 
   public void createImage(String file, String type, int quality)
   {
-    jalview.bin.Console.outPrintln("JMOL CREATE IMAGE");
+    System.out.println("JMOL CREATE IMAGE");
   }
 
   @Override
   public String createImage(String fileName, String type,
           Object textOrBytes, int quality)
   {
-    jalview.bin.Console.outPrintln("JMOL CREATE IMAGE");
+    System.out.println("JMOL CREATE IMAGE");
     return null;
   }
 
   @Override
   public String eval(String strEval)
   {
-    // jalview.bin.Console.outPrintln(strEval);
+    // System.out.println(strEval);
     // "# 'eval' is implemented only for the applet.";
     return null;
   }
@@ -187,27 +185,6 @@ public abstract class JalviewJmolBinding extends AAStructureBindingModel
   // End StructureListener
   // //////////////////////////
 
-  ////////////////////////////
-  // HETATM get
-  //
-
-  @Override
-  public Map<String, String> getHetatmNames()
-  {
-    HashMap<String, String> hetlist = new HashMap();
-    for (int mc = 0; mc < jmolViewer.ms.mc; mc++)
-    {
-      Map<String, String> hets = jmolViewer.ms.getHeteroList(mc);
-      if (hets != null)
-      {
-        hetlist.putAll(hets);
-      }
-    }
-    return hetlist;
-  }
-  //
-  ////////////////////////////
-
   @Override
   public float[][] functionXY(String functionName, int x, int y)
   {
@@ -290,33 +267,16 @@ public abstract class JalviewJmolBinding extends AAStructureBindingModel
   {
     if (atoms != null)
     {
+      boolean useScriptWait = atoms.size() > 1;
       if (resetLastRes.length() > 0)
       {
-        jmolScript(resetLastRes.toString());
+        jmolScript(resetLastRes.toString(), useScriptWait);
         resetLastRes.setLength(0);
       }
-      StringBuilder highlightCommands = null;
       for (AtomSpec atom : atoms)
       {
-        StringBuilder thisAtom = highlightAtom(atom.getAtomIndex(),
-                atom.getPdbResNum(), atom.getChain(), atom.getPdbFile());
-        if (thisAtom != null)
-        {
-          if (highlightCommands == null)
-          {
-            highlightCommands = thisAtom;
-          }
-          else
-          {
-            highlightCommands.append(thisAtom);
-          }
-        }
-      }
-      if (highlightCommands != null)
-      {
-        jmolHistory(false);
-        jmolScript(highlightCommands.toString());
-        jmolHistory(true);
+        highlightAtom(atom.getAtomIndex(), atom.getPdbResNum(),
+                atom.getChain(), atom.getPdbFile(), useScriptWait);
       }
       // Highlight distances between atoms with a 'measure' command - not yet
       // working
@@ -346,15 +306,17 @@ public abstract class JalviewJmolBinding extends AAStructureBindingModel
   }
 
   // jmol/ssm only
-  private StringBuilder highlightAtom(int atomIndex, int pdbResNum,
-          String chain, String pdbfile)
+  public void highlightAtom(int atomIndex, int pdbResNum, String chain,
+          String pdbfile, boolean useScriptWait)
   {
     String modelId = getModelIdForFile(pdbfile);
     if (modelId.isEmpty())
     {
-      return null;
+      return;
     }
 
+    jmolHistory(false, useScriptWait);
+
     StringBuilder selection = new StringBuilder(32);
     StringBuilder cmd = new StringBuilder(64);
     selection.append("select ").append(String.valueOf(pdbResNum));
@@ -371,7 +333,8 @@ public abstract class JalviewJmolBinding extends AAStructureBindingModel
     resetLastRes.append(selection).append(";wireframe 0;").append(selection)
             .append(" and not hetero; spacefill 0;");
 
-    return cmd;
+    jmolScript(cmd.toString(), useScriptWait);
+    jmolHistory(true, useScriptWait);
   }
 
   private boolean debug = true;
@@ -513,9 +476,8 @@ public abstract class JalviewJmolBinding extends AAStructureBindingModel
     lastMessage = strInfo;
     if (data != null)
     {
-      jalview.bin.Console.errPrintln(
-              "Ignoring additional hover info: " + data + " (other info: '"
-                      + strInfo + "' pos " + atomIndex + ")");
+      System.err.println("Ignoring additional hover info: " + data
+              + " (other info: '" + strInfo + "' pos " + atomIndex + ")");
     }
     mouseOverStructure(atomIndex, strInfo);
   }
@@ -535,8 +497,7 @@ public abstract class JalviewJmolBinding extends AAStructureBindingModel
      */
     if (strData != null)
     {
-      jalview.bin.Console.errPrintln(
-              "Ignoring additional pick data string " + strData);
+      System.err.println("Ignoring additional pick data string " + strData);
     }
     int chainSeparator = strInfo.indexOf(":");
     int p = 0;
@@ -638,7 +599,7 @@ public abstract class JalviewJmolBinding extends AAStructureBindingModel
                 (data == null) ? ((String) null) : (String) data[1]);
         break;
       case ERROR:
-        // jalview.bin.Console.errPrintln("Ignoring error callback.");
+        // System.err.println("Ignoring error callback.");
         break;
       case SYNC:
       case RESIZE:
@@ -648,14 +609,13 @@ public abstract class JalviewJmolBinding extends AAStructureBindingModel
 
       case CLICK:
       default:
-        jalview.bin.Console.errPrintln(
+        System.err.println(
                 "Unhandled callback " + type + " " + data[1].toString());
         break;
       }
     } catch (Exception e)
     {
-      jalview.bin.Console
-              .errPrintln("Squashed Jmol callback handler error:");
+      System.err.println("Squashed Jmol callback handler error:");
       e.printStackTrace();
     }
   }
@@ -904,9 +864,8 @@ public abstract class JalviewJmolBinding extends AAStructureBindingModel
   public void setCallbackFunction(String callbackType,
           String callbackFunction)
   {
-    jalview.bin.Console
-            .errPrintln("Ignoring set-callback request to associate "
-                    + callbackType + " with function " + callbackFunction);
+    System.err.println("Ignoring set-callback request to associate "
+            + callbackType + " with function " + callbackFunction);
 
   }
 
@@ -979,8 +938,7 @@ public abstract class JalviewJmolBinding extends AAStructureBindingModel
           String buttonsToShow)
   {
 
-    jalview.bin.Console
-            .errPrintln("Allocating Jmol Viewer: " + commandOptions);
+    System.err.println("Allocating Jmol Viewer: " + commandOptions);
 
     if (commandOptions == null)
     {
@@ -998,9 +956,8 @@ public abstract class JalviewJmolBinding extends AAStructureBindingModel
       console = createJmolConsole(consolePanel, buttonsToShow);
     } catch (Throwable e)
     {
-      jalview.bin.Console
-              .errPrintln("Could not create Jmol application console. "
-                      + e.getMessage());
+      System.err.println("Could not create Jmol application console. "
+              + e.getMessage());
       e.printStackTrace();
     }
     if (consolePanel != null)
