@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -207,7 +207,7 @@ public abstract class JalviewChimeraBinding extends AAStructureBindingModel
       startListening(chimeraListener.getUri());
     } catch (BindException e)
     {
-      jalview.bin.Console.errPrintln(
+      System.err.println(
               "Failed to start Chimera listener: " + e.getMessage());
     }
   }
@@ -568,7 +568,7 @@ public abstract class JalviewChimeraBinding extends AAStructureBindingModel
 
   private void log(String message)
   {
-    jalview.bin.Console.errPrintln("## Chimera log: " + message);
+    System.err.println("## Chimera log: " + message);
   }
 
   /**
@@ -627,9 +627,8 @@ public abstract class JalviewChimeraBinding extends AAStructureBindingModel
       executeCommand(false, null, command);
     } catch (IOException e)
     {
-      jalview.bin.Console.errPrintln(
-              "Sending commands to Chimera via file failed with "
-                      + e.getMessage());
+      System.err.println("Sending commands to Chimera via file failed with "
+              + e.getMessage());
     }
   }
 
