@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -175,7 +175,7 @@ public class PDBFTSRestClient extends FTSRestClient
 
       URI uri = webResource.getURI();
 
-      jalview.bin.Console.outPrintln(uri);
+      System.out.println(uri);
       ClientResponse clientResponse = null;
       int responseStatus = -1;
       // Get the JSON string from the response object or directly from the
@@ -183,8 +183,7 @@ public class PDBFTSRestClient extends FTSRestClient
       Map<String, Object> jsonObj = null;
       String responseString = null;
 
-      jalview.bin.Console
-              .outPrintln("query >>>>>>> " + pdbRestRequest.toString());
+      System.out.println("query >>>>>>> " + pdbRestRequest.toString());
 
       if (!isMocked())
       {
@@ -414,10 +413,10 @@ public class PDBFTSRestClient extends FTSRestClient
 
     for (FTSDataColumnI field : diplayFields)
     {
-      // jalview.bin.Console.outPrintln("Field " + field);
+      // System.out.println("Field " + field);
       String fieldData = (pdbJsonDoc.get(field.getCode()) == null) ? ""
               : pdbJsonDoc.get(field.getCode()).toString();
-      // jalview.bin.Console.outPrintln("Field Data : " + fieldData);
+      // System.out.println("Field Data : " + fieldData);
       if (field.isPrimaryKeyColumn())
       {
         primaryKey = fieldData;
@@ -441,7 +440,7 @@ public class PDBFTSRestClient extends FTSRestClient
         } catch (Exception e)
         {
           e.printStackTrace();
-          jalview.bin.Console.outPrintln("offending value:" + fieldData);
+          System.out.println("offending value:" + fieldData);
         }
       }
     }
