@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -20,7 +20,6 @@
  */
 package jalview.gui;
 
-import java.awt.Canvas;
 import java.awt.Color;
 import java.awt.Cursor;
 import java.awt.Dimension;
@@ -51,8 +50,6 @@ import javax.swing.ToolTipManager;
 
 import jalview.analysis.AlignSeq;
 import jalview.analysis.AlignmentUtils;
-import jalview.bin.Cache;
-import jalview.bin.Jalview;
 import jalview.datamodel.Alignment;
 import jalview.datamodel.AlignmentAnnotation;
 import jalview.datamodel.Annotation;
@@ -66,7 +63,6 @@ import jalview.io.FileFormat;
 import jalview.io.FormatAdapter;
 import jalview.util.Comparison;
 import jalview.util.MessageManager;
-import jalview.util.ParseHtmlBodyAndLinks;
 import jalview.util.Platform;
 
 /**
@@ -89,7 +85,7 @@ public class AnnotationLabels extends JPanel
   /**
    * height in pixels for allowing height adjuster to be active
    */
-  public static int HEIGHT_ADJUSTER_HEIGHT = 10;
+  private static int HEIGHT_ADJUSTER_HEIGHT = 10;
 
   private static final Font font = new Font("Arial", Font.PLAIN, 11);
 
@@ -117,8 +113,6 @@ public class AnnotationLabels extends JPanel
   private static final String COPYCONS_SEQ = MessageManager
           .getString("label.copy_consensus_sequence");
 
-  private static final String ADJUST_ANNOTATION_LABELS_WIDTH_PREF = "ADJUST_ANNOTATION_LABELS_WIDTH";
-
   private final boolean debugRedraw = false;
 
   private AlignmentPanel ap;
@@ -137,10 +131,6 @@ public class AnnotationLabels extends JPanel
 
   private boolean resizePanel = false;
 
-  private int annotationIdWidth = -1;
-
-  public static final String RESIZE_MARGINS_MARK_PREF = "RESIZE_MARGINS_MARK";
-
   /**
    * Creates a new AnnotationLabels object
    * 
@@ -148,6 +138,7 @@ public class AnnotationLabels extends JPanel
    */
   public AnnotationLabels(AlignmentPanel ap)
   {
+
     this.ap = ap;
     av = ap.av;
     ToolTipManager.sharedInstance().registerComponent(this);
@@ -192,7 +183,7 @@ public class AnnotationLabels extends JPanel
       for (int i = 0; i < aa.length; i++)
       {
         selectedRow = -1;
-        if (!aa[i].isForDisplay())
+        if (!aa[i].visible)
         {
           continue;
         }
@@ -427,74 +418,65 @@ public class AnnotationLabels extends JPanel
         pop.add(consclipbrd);
       }
 
-      addColourOrFilterByOptions(ap, aa[selectedRow], pop);
-
+      addColourOrFilterByOptions(ap,aa[selectedRow],pop);
+      
       if (aa[selectedRow].graph == AlignmentAnnotation.CONTACT_MAP)
       {
-        addContactMatrixOptions(ap, aa[selectedRow], pop);
-        // Set/adjust threshold for grouping ?
-        // colour alignment by this [type]
-        // select/hide columns by this row
-
+        addContactMatrixOptions(ap,aa[selectedRow],pop);
+          // Set/adjust threshold for grouping ?
+          // colour alignment by this [type]
+          // select/hide columns by this row
+          
+        }
       }
-    }
-
+    
     pop.show(this, evt.getX(), evt.getY());
   }
 
   static void addColourOrFilterByOptions(final AlignmentPanel ap,
-          final AlignmentAnnotation alignmentAnnotation,
-          final JPopupMenu pop)
+          final AlignmentAnnotation alignmentAnnotation, final JPopupMenu pop)
   {
     JMenuItem item;
-    item = new JMenuItem(
-            MessageManager.getString("label.colour_by_annotation"));
+    item = new JMenuItem(MessageManager.getString("label.colour_by_annotation"));
     item.addActionListener(new ActionListener()
     {
-
+      
       @Override
       public void actionPerformed(ActionEvent e)
       {
-        AnnotationColourChooser.displayFor(ap.av, ap, alignmentAnnotation,
-                false);
+        AnnotationColourChooser.displayFor(ap.av, ap,alignmentAnnotation,false);
       };
     });
     pop.add(item);
-    if (alignmentAnnotation.sequenceRef != null)
+    if (alignmentAnnotation.sequenceRef!=null)
     {
-      item = new JMenuItem(
-              MessageManager.getString("label.colour_by_annotation") + " ("
-                      + MessageManager.getString("label.per_seq") + ")");
+      item = new JMenuItem(MessageManager.getString("label.colour_by_annotation")+" ("+MessageManager.getString("label.per_seq")+")");
       item.addActionListener(new ActionListener()
       {
         @Override
         public void actionPerformed(ActionEvent e)
         {
-          AnnotationColourChooser.displayFor(ap.av, ap, alignmentAnnotation,
-                  true);
+          AnnotationColourChooser.displayFor(ap.av, ap,alignmentAnnotation,true);
         };
       });
       pop.add(item);
     }
-    item = new JMenuItem(
-            MessageManager.getString("action.select_by_annotation"));
+    item = new JMenuItem(MessageManager.getString("action.select_by_annotation"));
     item.addActionListener(new ActionListener()
     {
-
+      
       @Override
       public void actionPerformed(ActionEvent e)
       {
-        AnnotationColumnChooser.displayFor(ap.av, ap, alignmentAnnotation);
+        AnnotationColumnChooser.displayFor(ap.av,ap,alignmentAnnotation);
       };
     });
     pop.add(item);
   }
-
   static void addContactMatrixOptions(final AlignmentPanel ap,
-          final AlignmentAnnotation alignmentAnnotation,
-          final JPopupMenu pop)
+          final AlignmentAnnotation alignmentAnnotation, final JPopupMenu pop)
   {
-
+    
     final ContactMatrixI cm = ap.av.getContactMatrix(alignmentAnnotation);
     JMenuItem item;
     if (cm != null)
@@ -503,13 +485,10 @@ public class AnnotationLabels extends JPanel
 
       if (cm.hasGroups())
       {
-        JCheckBoxMenuItem chitem = new JCheckBoxMenuItem(
-                MessageManager.getString("action.show_groups_on_matrix"));
-        chitem.setToolTipText(MessageManager
-                .getString("action.show_groups_on_matrix_tooltip"));
-        boolean showGroups = alignmentAnnotation
-                .isShowGroupsForContactMatrix();
-        final AlignmentAnnotation sel_row = alignmentAnnotation;
+        JCheckBoxMenuItem chitem = new JCheckBoxMenuItem(MessageManager.getString("action.show_groups_on_matrix"));
+        chitem.setToolTipText(MessageManager.getString("action.show_groups_on_matrix_tooltip"));
+        boolean showGroups = alignmentAnnotation.isShowGroupsForContactMatrix();
+        final AlignmentAnnotation sel_row=alignmentAnnotation;
         chitem.setState(showGroups);
         chitem.addActionListener(new ActionListener()
         {
@@ -528,10 +507,8 @@ public class AnnotationLabels extends JPanel
       }
       if (cm.hasTree())
       {
-        item = new JMenuItem(
-                MessageManager.getString("action.show_tree_for_matrix"));
-        item.setToolTipText(MessageManager
-                .getString("action.show_tree_for_matrix_tooltip"));
+        item = new JMenuItem(MessageManager.getString("action.show_tree_for_matrix"));
+        item.setToolTipText(MessageManager.getString("action.show_tree_for_matrix_tooltip"));
         item.addActionListener(new ActionListener()
         {
 
@@ -547,10 +524,8 @@ public class AnnotationLabels extends JPanel
       }
       else
       {
-        item = new JMenuItem(
-                MessageManager.getString("action.cluster_matrix"));
-        item.setToolTipText(
-                MessageManager.getString("action.cluster_matrix_tooltip"));
+        item = new JMenuItem(MessageManager.getString("action.cluster_matrix"));
+        item.setToolTipText(MessageManager.getString("action.cluster_matrix_tooltip"));
         item.addActionListener(new ActionListener()
         {
           @Override
@@ -562,11 +537,7 @@ public class AnnotationLabels extends JPanel
               public void run()
               {
                 final long progBar;
-                ap.alignFrame.setProgressBar(
-                        MessageManager.formatMessage(
-                                "action.clustering_matrix_for",
-                                cm.getAnnotDescr(), 5f),
-                        progBar = System.currentTimeMillis());
+                ap.alignFrame.setProgressBar(MessageManager.formatMessage("action.clustering_matrix_for",cm.getAnnotDescr(),5f), progBar = System.currentTimeMillis());
                 cm.setGroupSet(GroupSet.makeGroups(cm, true));
                 cm.randomlyReColourGroups();
                 cm.transferGroupColorsTo(alignmentAnnotation);
@@ -794,15 +765,9 @@ public class AnnotationLabels extends JPanel
     {
       Dimension d = ap.annotationScroller.getPreferredSize();
       int dif = evt.getY() - oldY;
-      dif -= dif % ap.av.getCharHeight();
 
-      // don't allow setting an annotation panel height larger than visible
-      // (otherwise you can't get back)
-      if (d.height - dif > ap.idPanelHolder.getHeight()
-              - ap.getIdSpaceFillerPanel1().getHeight())
-      {
-        return;
-      }
+      dif /= ap.av.getCharHeight();
+      dif *= ap.av.getCharHeight();
 
       if ((d.height - dif) > 20)
       {
@@ -1119,7 +1084,7 @@ public class AnnotationLabels extends JPanel
     if (av.hasHiddenColumns())
     {
       Iterator<int[]> it = av.getAlignment().getHiddenColumns()
-              .getVisContigsIterator(0, sq.getLength() + 1, false);
+              .getVisContigsIterator(0, sq.getLength(), false);
       omitHidden = new String[] { sq.getSequenceStringFromIterator(it) };
     }
 
@@ -1175,7 +1140,8 @@ public class AnnotationLabels extends JPanel
               RenderingHints.VALUE_ANTIALIAS_ON);
     }
 
-    drawComponent(g2, true, width, true);
+    drawComponent(g2, true, width);
+
   }
 
   /**
@@ -1190,7 +1156,7 @@ public class AnnotationLabels extends JPanel
    */
   public void drawComponent(Graphics g, int width)
   {
-    drawComponent(g, false, width, true);
+    drawComponent(g, false, width);
   }
 
   /**
@@ -1205,159 +1171,32 @@ public class AnnotationLabels extends JPanel
    * @param width
    *          Width for scaling labels
    */
-  public void drawComponent(Graphics g, boolean clip, int givenWidth,
-          boolean forGUI)
+  public void drawComponent(Graphics g, boolean clip, int width)
   {
-    int width = givenWidth;
-    IdwidthAdjuster iwa = null;
-    if (ap != null)
+    if (av.getFont().getSize() < 10)
     {
-      iwa = ap.idwidthAdjuster;
-      if (Cache.getDefault(ADJUST_ANNOTATION_LABELS_WIDTH_PREF, true)
-              || Jalview.isHeadlessMode())
-      {
-        Graphics2D g2d = (Graphics2D) g;
-        Graphics dummy = g2d.create();
-        int newAnnotationIdWidth = drawLabels(dummy, clip, width, false,
-                forGUI, null, false);
-        dummy.dispose();
-        Dimension d = ap.calculateDefaultAlignmentIdWidth();
-        int alignmentIdWidth = d.width;
-        if (iwa != null && !iwa.manuallyAdjusted())
-        {
-          // If no manual adjustment to ID column with has been made then adjust
-          // width match widest of alignment or annotation id widths
-          boolean allowShrink = Cache.getDefault("ALLOW_SHRINK_ID_WIDTH",
-                  false);
-          width = Math.max(alignmentIdWidth, newAnnotationIdWidth);
-          if (clip && width < givenWidth && !allowShrink)
-          {
-            width = givenWidth;
-          }
-        }
-        else if (newAnnotationIdWidth != annotationIdWidth
-                && newAnnotationIdWidth > givenWidth
-                && newAnnotationIdWidth > alignmentIdWidth)
-        {
-          // otherwise if the annotation id width has become larger than the
-          // current id width, increase
-          width = newAnnotationIdWidth;
-          annotationIdWidth = newAnnotationIdWidth;
-        }
-        // set the width if it's changed
-        if (width != ap.av.getIdWidth())
-        {
-          iwa.setWidth(width);
-        }
-      }
+      g.setFont(font);
     }
     else
     {
-      int newAnnotationIdWidth = drawLabels(g, clip, width, false, forGUI,
-              null, false);
-      width = newAnnotationIdWidth < givenWidth ? givenWidth
-              : Math.min(newAnnotationIdWidth, givenWidth);
-    }
-    drawLabels(g, clip, width, true, forGUI, null, false);
-  }
-
-  /**
-   * Render the full set of annotation Labels for the alignment at the given
-   * cursor. If actuallyDraw is false or g is null then no actual drawing will
-   * occur, but the widest label width will be returned. If g is null then
-   * fmetrics must be supplied.
-   * 
-   * @param g
-   *          Graphics2D instance (used for rendering and font scaling if no
-   *          fmetrics supplied)
-   * @param clip
-   *          - true indicates that only current visible area needs to be
-   *          rendered
-   * @param width
-   *          Width for scaling labels
-   * @param actuallyDraw
-   *          - when false, no graphics are rendered to g0
-   * @param forGUI
-   *          - when false, GUI relevant marks like indicators for dragging
-   *          annotation panel height are not rendered
-   * @param fmetrics
-   *          FontMetrics if Graphics object g is null
-   * @param includeHidden
-   *          - when true returned width includes labels in hidden row width
-   *          calculation
-   * @return the width of the annotation labels.
-   */
-  public int drawLabels(Graphics g0, boolean clip, int width,
-          boolean actuallyDraw, boolean forGUI, FontMetrics fmetrics,
-          boolean includeHidden)
-  {
-    if (clip)
-    {
-      clip = Cache.getDefault("MOVE_SEQUENCE_ID_WITH_VISIBLE_ANNOTATIONS",
-              true);
-    }
-    Graphics g = null;
-    // create a dummy Graphics object if not drawing and one is supplied
-    if (g0 != null)
-    {
-      if (!actuallyDraw)
-      {
-        Graphics2D g2d = (Graphics2D) g0;
-        g = g2d.create();
-      }
-      else
-      {
-        g = g0;
-      }
-    }
-    int actualWidth = 0;
-    if (g != null)
-    {
-      if (av.getFont().getSize() < 10)
-      {
-        g.setFont(font);
-      }
-      else
-      {
-        g.setFont(av.getFont());
-      }
+      g.setFont(av.getFont());
     }
 
-    FontMetrics fm = fmetrics == null ? g.getFontMetrics(g.getFont())
-            : fmetrics;
-    if (actuallyDraw)
-    {
-      g.setColor(Color.white);
-      g.fillRect(0, 0, getWidth(), getHeight());
+    FontMetrics fm = g.getFontMetrics(g.getFont());
+    g.setColor(Color.white);
+    g.fillRect(0, 0, getWidth(), getHeight());
 
-      if (!Cache.getDefault(RESIZE_MARGINS_MARK_PREF, false)
-              && !av.getWrapAlignment() && forGUI)
-      {
-        g.setColor(Color.LIGHT_GRAY);
-        g.drawLine(0, HEIGHT_ADJUSTER_HEIGHT / 4, HEIGHT_ADJUSTER_WIDTH / 4,
-                HEIGHT_ADJUSTER_HEIGHT / 4);
-        g.drawLine(0, 3 * HEIGHT_ADJUSTER_HEIGHT / 4,
-                HEIGHT_ADJUSTER_WIDTH / 4, 3 * HEIGHT_ADJUSTER_HEIGHT / 4);
-
-      }
-    }
-
-    if (actuallyDraw)
-    {
-      g.translate(0, getScrollOffset());
-      g.setColor(Color.black);
-    }
+    g.translate(0, getScrollOffset());
+    g.setColor(Color.black);
     SequenceI lastSeqRef = null;
     String lastLabel = null;
-    String lastDescription = null;
     AlignmentAnnotation[] aa = av.getAlignment().getAlignmentAnnotation();
-    int fontHeight = g != null ? g.getFont().getSize()
-            : fm.getFont().getSize();
+    int fontHeight = g.getFont().getSize();
     int y = 0;
     int x = 0;
     int graphExtras = 0;
     int offset = 0;
-    Font baseFont = g != null ? g.getFont() : fm.getFont();
+    Font baseFont = g.getFont();
     FontMetrics baseMetrics = fm;
     int ofontH = fontHeight;
     int sOffset = 0;
@@ -1379,7 +1218,7 @@ public class AnnotationLabels extends JPanel
       for (int i = 0; i < aa.length; i++)
       {
         visible = true;
-        if (!aa[i].isForDisplay() && !includeHidden)
+        if (!aa[i].visible)
         {
           hasHiddenRows = true;
           continue;
@@ -1387,7 +1226,7 @@ public class AnnotationLabels extends JPanel
         olY = y;
         // look ahead to next annotation
         for (nexAA = i + 1; nexAA < aa.length
-                && (!aa[nexAA].isForDisplay() && includeHidden); nexAA++)
+                && !aa[nexAA].visible; nexAA++)
           ;
         y += aa[i].height;
         if (clip)
@@ -1398,7 +1237,7 @@ public class AnnotationLabels extends JPanel
             {
               if (debugRedraw)
               {
-                jalview.bin.Console.outPrintln("before vis: " + i);
+                System.out.println("before vis: " + i);
               }
               before = true;
             }
@@ -1412,7 +1251,7 @@ public class AnnotationLabels extends JPanel
             {
               if (debugRedraw)
               {
-                jalview.bin.Console.outPrintln(
+                System.out.println(
                         "Scroll offset: " + sOffset + " after vis: " + i);
               }
               after = true;
@@ -1421,10 +1260,8 @@ public class AnnotationLabels extends JPanel
             continue;
           }
         }
-        if (actuallyDraw && g != null)
-        {
-          g.setColor(Color.black);
-        }
+        g.setColor(Color.black);
+
         offset = -aa[i].height / 2;
 
         if (aa[i].hasText)
@@ -1437,24 +1274,10 @@ public class AnnotationLabels extends JPanel
           offset += fm.getDescent();
         }
         String label = aa[i].label;
-        ParseHtmlBodyAndLinks phbDecription = new ParseHtmlBodyAndLinks(
-                aa[i].description, true, "\n");
-        String description = phbDecription.getNonHtmlContent();
         boolean vertBar = false;
-        if (lastLabel != null && lastLabel.equals(label) && 
-                lastDescription != null && lastDescription.equals(description))
+        if ((lastLabel != null && lastLabel.equals(label)))
         {
-          //JAL-4427
-          label = aa[i].label; // No change in label
-        }
-        else if (lastLabel != null && lastLabel.equals(label))
-        {
-          //JAL-4427
-          if(!(lastDescription != null && lastDescription.equals(description))
-                  &&  (aa[i].sequenceRef == lastSeqRef)) {
-              label = description;
-              lastDescription = description;
-          }
+          label = aa[i].description;
         }
         else
         {
@@ -1463,18 +1286,11 @@ public class AnnotationLabels extends JPanel
           {
             lastLabel = label;
             // next label is the same as this label
-            //JAL-4427
-            if((lastDescription != null && !lastDescription.equals(description))) {
-              if(aa[nexAA].sequenceRef == aa[i].sequenceRef) {
-                label = description;
-              }
-              lastDescription = description;
-            }
+            label = aa[i].description;
           }
           else
           {
             lastLabel = label;
-            lastDescription = description;
           }
         }
         if (aa[i].sequenceRef != null)
@@ -1490,9 +1306,7 @@ public class AnnotationLabels extends JPanel
             vertBar = true;
           }
         }
-
-        int labelWidth = fm.stringWidth(label) + 3;
-        x = width - labelWidth;
+        x = width - fm.stringWidth(label) - 3;
 
         if (aa[i].graphGroup > -1)
         {
@@ -1525,15 +1339,10 @@ public class AnnotationLabels extends JPanel
               s = ((float) fontHeight) / (float) ofontH;
               Font f = baseFont
                       .deriveFont(AffineTransform.getScaleInstance(s, s));
-              Canvas c = new Canvas();
-              fm = c.getFontMetrics(f);
-              if (actuallyDraw && g != null)
-              {
-                g.setFont(f);
-                // fm = g.getFontMetrics();
-                graphExtras = (aa[i].height
-                        - (groupSize * (fontHeight + 8))) / 2;
-              }
+              g.setFont(f);
+              fm = g.getFontMetrics();
+              graphExtras = (aa[i].height - (groupSize * (fontHeight + 8)))
+                      / 2;
             }
           }
           if (visible)
@@ -1542,82 +1351,58 @@ public class AnnotationLabels extends JPanel
             {
               if (aa[gg].graphGroup == aa[i].graphGroup)
               {
-                labelWidth = fm.stringWidth(aa[gg].label) + 3;
-                x = width - labelWidth;
-                if (actuallyDraw && g != null)
+                x = width - fm.stringWidth(aa[gg].label) - 3;
+                g.drawString(aa[gg].label, x, y - graphExtras);
+
+                if (aa[gg]._linecolour != null)
                 {
-                  g.drawString(aa[gg].label, x, y - graphExtras);
 
-                  if (aa[gg]._linecolour != null)
-                  {
-
-                    g.setColor(aa[gg]._linecolour);
-                    g.drawLine(x, y - graphExtras + 3,
-                            x + fm.stringWidth(aa[gg].label),
-                            y - graphExtras + 3);
-                  }
-
-                  g.setColor(Color.black);
+                  g.setColor(aa[gg]._linecolour);
+                  g.drawLine(x, y - graphExtras + 3,
+                          x + fm.stringWidth(aa[gg].label),
+                          y - graphExtras + 3);
                 }
+
+                g.setColor(Color.black);
                 graphExtras += fontHeight + 8;
               }
             }
           }
-          if (actuallyDraw && g != null)
-          {
-            g.setFont(baseFont);
-          }
+          g.setFont(baseFont);
           fm = baseMetrics;
           fontHeight = ofontH;
         }
         else
         {
-          if (actuallyDraw && g != null)
+          if (vertBar)
           {
-            if (vertBar)
-            {
-              g.drawLine(width - 3, y + offset - fontHeight, width - 3,
-                      (int) (y - 1.5 * aa[i].height - offset - fontHeight));
-              // g.drawLine(20, y + offset, x - 20, y + offset);
+            g.drawLine(width - 3, y + offset - fontHeight, width - 3,
+                    (int) (y - 1.5 * aa[i].height - offset - fontHeight));
+            // g.drawLine(20, y + offset, x - 20, y + offset);
 
-            }
-            g.drawString(label, x, y + offset);
           }
+          g.drawString(label, x, y + offset);
         }
         lastSeqRef = aa[i].sequenceRef;
-
-        if (labelWidth > actualWidth)
-        {
-          actualWidth = labelWidth;
-        }
       }
     }
 
-    if (!resizePanel && dragEvent != null && aa != null && selectedRow > -1
-            && selectedRow < aa.length)
+    if (!resizePanel && dragEvent != null && aa != null)
     {
-      if (actuallyDraw && g != null)
-      {
-        g.setColor(Color.lightGray);
-        g.drawString(
-                (aa[selectedRow].sequenceRef == null ? ""
-                        : aa[selectedRow].sequenceRef.getName())
-                        + aa[selectedRow].label,
-                dragEvent.getX(), dragEvent.getY() - getScrollOffset());
-      }
+      g.setColor(Color.lightGray);
+      g.drawString(
+              (aa[selectedRow].sequenceRef == null ? ""
+                      : aa[selectedRow].sequenceRef.getName())
+                      + aa[selectedRow].label,
+              dragEvent.getX(), dragEvent.getY() - getScrollOffset());
     }
 
     if (!av.getWrapAlignment() && ((aa == null) || (aa.length < 1)))
     {
-      if (actuallyDraw && g != null)
-      {
-        g.drawString(MessageManager.getString("label.right_click"), 2, 8);
-        g.drawString(MessageManager.getString("label.to_add_annotation"), 2,
-                18);
-      }
+      g.drawString(MessageManager.getString("label.right_click"), 2, 8);
+      g.drawString(MessageManager.getString("label.to_add_annotation"), 2,
+              18);
     }
-
-    return actualWidth;
   }
 
   public int getScrollOffset()
@@ -1629,9 +1414,4 @@ public class AnnotationLabels extends JPanel
   public void mouseEntered(MouseEvent e)
   {
   }
-
-  public void drawComponentNotGUI(Graphics idGraphics, int idWidth)
-  {
-    drawComponent(idGraphics, false, idWidth, false);
-  }
 }
