@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -28,10 +28,16 @@ import java.awt.Graphics;
 import java.awt.Graphics2D;
 import java.awt.RenderingHints;
 import java.io.File;
+import java.lang.reflect.InvocationTargetException;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
+import java.util.concurrent.Callable;
+import java.util.concurrent.CompletableFuture;
+import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
+import java.util.concurrent.Future;
+import java.util.concurrent.FutureTask;
 
 import javax.swing.JPanel;
 import javax.swing.JSplitPane;
@@ -264,8 +270,6 @@ public class AppJmol extends StructureViewerBase
     }
     jmb.executeCommand(new StructureCommand(command), false);
     jmb.executeCommand(new StructureCommand("set hoverDelay=0.1"), false);
-    jmb.executeCommand(new StructureCommand("set antialiasdisplay on"),
-            false);
     jmb.setFinishedInit(true);
   }
 
@@ -367,10 +371,9 @@ public class AppJmol extends StructureViewerBase
       }
       if (waitTotal > waitMax)
       {
-        jalview.bin.Console.errPrintln(
-                "Timed out waiting for Jmol to load files after "
-                        + waitTotal + "ms");
-        // jalview.bin.Console.errPrintln("finished: " + jmb.isFinishedInit()
+        System.err.println("Timed out waiting for Jmol to load files after "
+                + waitTotal + "ms");
+        // System.err.println("finished: " + jmb.isFinishedInit()
         // + "; loaded: " + Arrays.toString(jmb.getPdbFile())
         // + "; files: " + files.toString());
         jmb.getStructureFiles();
@@ -421,15 +424,6 @@ public class AppJmol extends StructureViewerBase
 
   }
 
-  public boolean isRepainting()
-  {
-    if (renderPanel != null && renderPanel.isVisible())
-    {
-      return renderPanel.repainting;
-    }
-    return false;
-  }
-
   /**
    * Outputs the Jmol viewer image as an image file, after prompting the user to
    * choose a file and (for EPS) choice of Text or Lineart character rendering
@@ -440,23 +434,11 @@ public class AppJmol extends StructureViewerBase
   @Override
   public void makePDBImage(ImageMaker.TYPE type)
   {
-    while (!isRepainting())
-    {
-      try
-      {
-        Thread.sleep(2);
-      } catch (Exception q)
-      {
-      }
-    }
-    try
-    {
-      makePDBImage(null, type, null,
-              BitmapImageSizing.defaultBitmapImageSizing());
-    } catch (ImageOutputException ioex)
-    {
-      Console.error("Unexpected error whilst writing " + type.toString(),
-              ioex);
+    try {
+    makePDBImage(null, type, null,
+            BitmapImageSizing.nullBitmapImageSizing());
+    } catch (ImageOutputException ioex) {
+      Console.error("Unexpected error whilst writing "+type.toString(),ioex);
     }
   }
 
@@ -468,9 +450,9 @@ public class AppJmol extends StructureViewerBase
 
     BitmapImageSizing bis = ImageMaker.getScaleWidthHeight(width, height,
             userBis);
-    float usescale = bis.scale();
-    int usewidth = bis.width();
-    int useheight = bis.height();
+    float usescale = bis.scale;
+    int usewidth = bis.width;
+    int useheight = bis.height;
 
     ImageWriterI writer = new ImageWriterI()
     {
@@ -490,6 +472,7 @@ public class AppJmol extends StructureViewerBase
           }
         }
 
+        jmb.jmolViewer.antialiased = true;
         jmb.jmolViewer.requestRepaintAndWait("image export");
         jmb.jmolViewer.renderScreenImage(ig2, usewidth, useheight);
       }
@@ -498,40 +481,29 @@ public class AppJmol extends StructureViewerBase
             .toLowerCase(Locale.ROOT);
     final ImageExporter exporter = new ImageExporter(writer,
             getProgressIndicator(), type, getTitle());
-
+    
     final Throwable[] exceptions = new Throwable[1];
     exceptions[0] = null;
     final AppJmol us = this;
     try
     {
-      Thread runner = Executors.defaultThreadFactory()
-              .newThread(new Runnable()
-              {
-                @Override
-                public void run()
-                {
-                  try
-                  {
-                    exporter.doExport(file, us, width, height, view,
-                            renderer, userBis);
-                  } catch (Throwable t)
-                  {
-                    exceptions[0] = t;
-                  }
-                }
-              });
+      Thread runner = Executors.defaultThreadFactory().newThread(new Runnable()
+      {
+        @Override
+        public void run()
+        {
+          try
+          {
+            exporter.doExport(file, us, width, height, view, renderer,
+                    userBis);
+          } catch (Throwable t)
+          {
+            exceptions[0] = t;
+          }
+        }
+      });
       runner.start();
-      long time = 0;
-      do
-      {
-        Thread.sleep(25);
-      } while (runner.isAlive() && time++ < 4000);
-      if (time >= 4000)
-      {
-        runner.interrupt();
-        throw new ImageOutputException(
-                "Jmol took too long to export. Waited for 100 seconds.");
-      }
+      do { Thread.sleep(25); } while (runner.isAlive());
     } catch (Throwable e)
     {
       throw new ImageOutputException(
@@ -560,8 +532,7 @@ public class AppJmol extends StructureViewerBase
               .openURL("http://wiki.jmol.org");// http://jmol.sourceforge.net/docs/JmolUserGuide/");
     } catch (Exception ex)
     {
-      jalview.bin.Console
-              .errPrintln("Show Jmol help failed with: " + ex.getMessage());
+      System.err.println("Show Jmol help failed with: " + ex.getMessage());
     }
   }
 
@@ -645,18 +616,10 @@ public class AppJmol extends StructureViewerBase
       }
       else
       {
-        repainting = true;
-        synchronized (jmb)
-        {
-          jmb.jmolViewer.renderScreenImage(g, currentSize.width,
-                  currentSize.height);
-
-        }
-        repainting = false;
+        jmb.jmolViewer.renderScreenImage(g, currentSize.width,
+                currentSize.height);
       }
     }
-
-    volatile boolean repainting = false;
   }
 
   @Override
