@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -45,7 +45,6 @@ import java.io.FileOutputStream;
 import java.io.InputStreamReader;
 import java.io.OutputStreamWriter;
 import java.io.PrintWriter;
-import java.io.Reader;
 import java.util.Arrays;
 import java.util.Comparator;
 import java.util.HashMap;
@@ -104,8 +103,6 @@ import jalview.datamodel.features.FeatureMatcherSet;
 import jalview.datamodel.features.FeatureMatcherSetI;
 import jalview.gui.Help.HelpId;
 import jalview.gui.JalviewColourChooser.ColourChooserListener;
-import jalview.io.DataSourceType;
-import jalview.io.FileParse;
 import jalview.io.JalviewFileChooser;
 import jalview.io.JalviewFileView;
 import jalview.schemes.FeatureColour;
@@ -958,87 +955,57 @@ public class FeatureSettings extends JPanel
     chooser.showOpenDialog(this);
   }
 
-  public static boolean loadFeatureSettingsFile(FeatureRenderer fr,
-          File file) throws Exception
-  {
-    InputStreamReader in = new InputStreamReader(new FileInputStream(file),
-            "UTF-8");
-    return loadFeatureSettingsFile(fr, in);
-  }
-
-  public static void loadFeatureSettingsFile(
-          FeatureRenderer featureRenderer, Object fileObject,
-          DataSourceType sourceType) throws Exception
-  {
-    FileParse fp = new FileParse(fileObject, sourceType);
-    loadFeatureSettingsFile(featureRenderer, fp.getReader());
-  }
-
-  private static boolean loadFeatureSettingsFile(FeatureRenderer fr,
-          Reader in) throws Exception
-  {
-    JAXBContext jc = JAXBContext.newInstance("jalview.xml.binding.jalview");
-    javax.xml.bind.Unmarshaller um = jc.createUnmarshaller();
-    XMLStreamReader streamReader = XMLInputFactory.newInstance()
-            .createXMLStreamReader(in);
-    JAXBElement<JalviewUserColours> jbe = um.unmarshal(streamReader,
-            JalviewUserColours.class);
-    JalviewUserColours jucs = jbe.getValue();
-
-    // JalviewUserColours jucs = JalviewUserColours.unmarshal(in);
-
-    /*
-     * load feature colours
-     */
-    for (int i = jucs.getColour().size() - 1; i >= 0; i--)
-    {
-      Colour newcol = jucs.getColour().get(i);
-      FeatureColourI colour = jalview.project.Jalview2XML
-              .parseColour(newcol);
-      fr.setColour(newcol.getName(), colour);
-      fr.setOrder(newcol.getName(), i / (float) jucs.getColour().size());
-    }
-
-    /*
-     * load feature filters; loaded filters will replace any that are
-     * currently defined, other defined filters are left unchanged 
-     */
-    for (int i = 0; i < jucs.getFilter().size(); i++)
-    {
-      Filter filterModel = jucs.getFilter().get(i);
-      String featureType = filterModel.getFeatureType();
-      FeatureMatcherSetI filter = jalview.project.Jalview2XML
-              .parseFilter(featureType, filterModel.getMatcherSet());
-      if (!filter.isEmpty())
-      {
-        fr.setFeatureFilter(featureType, filter);
-      }
-    }
-    return true;
-  }
-
   /**
    * Loads feature colours and filters from XML stored in the given file
    * 
    * @param file
    */
   void load(File file)
-  {
-    load(file, DataSourceType.FILE);
-  }
-
-  /**
-   * Loads feature colours and filters from XML at a specified source
-   * 
-   * @param file
-   *          - string or file or other object that allows FileParse to be
-   *          created
-   */
-  void load(Object file, DataSourceType sourceType)
   {
     try
     {
-      loadFeatureSettingsFile(fr, file, sourceType);
+      InputStreamReader in = new InputStreamReader(
+              new FileInputStream(file), "UTF-8");
+
+      JAXBContext jc = JAXBContext
+              .newInstance("jalview.xml.binding.jalview");
+      javax.xml.bind.Unmarshaller um = jc.createUnmarshaller();
+      XMLStreamReader streamReader = XMLInputFactory.newInstance()
+              .createXMLStreamReader(in);
+      JAXBElement<JalviewUserColours> jbe = um.unmarshal(streamReader,
+              JalviewUserColours.class);
+      JalviewUserColours jucs = jbe.getValue();
+
+      // JalviewUserColours jucs = JalviewUserColours.unmarshal(in);
+
+      /*
+       * load feature colours
+       */
+      for (int i = jucs.getColour().size() - 1; i >= 0; i--)
+      {
+        Colour newcol = jucs.getColour().get(i);
+        FeatureColourI colour = jalview.project.Jalview2XML
+                .parseColour(newcol);
+        fr.setColour(newcol.getName(), colour);
+        fr.setOrder(newcol.getName(), i / (float) jucs.getColour().size());
+      }
+
+      /*
+       * load feature filters; loaded filters will replace any that are
+       * currently defined, other defined filters are left unchanged 
+       */
+      for (int i = 0; i < jucs.getFilter().size(); i++)
+      {
+        Filter filterModel = jucs.getFilter().get(i);
+        String featureType = filterModel.getFeatureType();
+        FeatureMatcherSetI filter = jalview.project.Jalview2XML
+                .parseFilter(featureType, filterModel.getMatcherSet());
+        if (!filter.isEmpty())
+        {
+          fr.setFeatureFilter(featureType, filter);
+        }
+      }
+
       /*
        * update feature settings table
        */
@@ -1052,8 +1019,7 @@ public class FeatureSettings extends JPanel
       }
     } catch (Exception ex)
     {
-      jalview.bin.Console
-              .outPrintln("Error loading User Colour File\n" + ex);
+      System.out.println("Error loading User Colour File\n" + ex);
     }
   }
 
@@ -1642,7 +1608,7 @@ public class FeatureSettings extends JPanel
     {
       Color newColor = gcol.getMaxColour();
       comp.setBackground(newColor);
-      // jalview.bin.Console.errPrintln("Width is " + w / 2);
+      // System.err.println("Width is " + w / 2);
       Icon ficon = new FeatureIcon(gcol, comp.getBackground(), w, h, thr);
       comp.setIcon(ficon);
       // tt+="RGB value: Max (" + newColor.getRed() + ", "
@@ -1821,15 +1787,11 @@ public class FeatureSettings extends JPanel
     {
       FeatureMatcherSetI theFilter = (FeatureMatcherSetI) filter;
       setOpaque(true);
+      String asText = theFilter.toString();
       setBackground(tbl.getBackground());
+      this.setText(asText);
       this.setIcon(null);
 
-      if (theFilter != null)
-      {
-        String asText = theFilter.toString();
-        this.setText(asText);
-      }
-
       if (isSelected)
       {
         if (selectedBorder == null)
@@ -1919,9 +1881,6 @@ public class FeatureSettings extends JPanel
            */
           String ttl = MessageManager
                   .formatMessage("label.select_colour_for", type);
-          Object last = (Boolean) table.getValueAt(selectedRow,
-                  SHOW_COLUMN);
-          table.setValueAt(Boolean.TRUE, selectedRow, SHOW_COLUMN);
           ColourChooserListener listener = new ColourChooserListener()
           {
             @Override
@@ -1929,14 +1888,12 @@ public class FeatureSettings extends JPanel
             {
               currentColor = new FeatureColour(c);
               table.setValueAt(currentColor, rowSelected, COLOUR_COLUMN);
-              table.setValueAt(Boolean.TRUE, selectedRow, SHOW_COLUMN);
               fireEditingStopped();
             }
 
             @Override
             public void cancel()
             {
-              table.setValueAt(last, selectedRow, SHOW_COLUMN);
               fireEditingStopped();
             }
           };
@@ -1948,10 +1905,7 @@ public class FeatureSettings extends JPanel
           /*
            * variable colour and filters dialog
            */
-          boolean last = (Boolean) table.getValueAt(selectedRow,
-                  SHOW_COLUMN);
-          table.setValueAt(Boolean.TRUE, selectedRow, SHOW_COLUMN);
-          chooser = new FeatureTypeSettings(fr, type, last);
+          chooser = new FeatureTypeSettings(fr, type);
           if (!Platform.isJS())
           /**
            * Java only
@@ -2077,11 +2031,7 @@ public class FeatureSettings extends JPanel
     {
       if (button == e.getSource())
       {
-        boolean last = fr.getFeaturesDisplayed().isVisible(type);
-        ((FeatureTableModel) table.getModel()).setValueAt(Boolean.TRUE,
-                rowSelected, SHOW_COLUMN);
-        FeatureTypeSettings chooser = new FeatureTypeSettings(fr, type,
-                last);
+        FeatureTypeSettings chooser = new FeatureTypeSettings(fr, type);
         chooser.addActionListener(this);
         chooser.setRequestFocusEnabled(true);
         chooser.requestFocus();
@@ -2113,8 +2063,6 @@ public class FeatureSettings extends JPanel
                 .getData()[rowSelected];
         data[COLOUR_COLUMN] = currentColor;
         data[FILTER_COLUMN] = currentFilter;
-        data[SHOW_COLUMN] = fr.getFeaturesDisplayed().isVisible(type);
-
         fireEditingStopped();
         // SwingJS needs an explicit repaint() here,
         // rather than relying upon no validation having
