@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -713,7 +713,7 @@ public class OptsAndParamsPage
             }
           } catch (NumberFormatException e)
           {
-            jalview.bin.Console.errPrintln(e.toString());
+            System.err.println(e.toString());
           }
           if (minValue != null || maxValue != null)
           {
@@ -750,7 +750,7 @@ public class OptsAndParamsPage
             }
           } catch (NumberFormatException e)
           {
-            jalview.bin.Console.errPrintln(e.toString());
+            System.err.println(e.toString());
           }
           if (minValue != null && maxValue != null)
           {
