@@ -1,5 +1,5 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
+ * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.1)
  * Copyright (C) 2024 The Jalview Authors
  * 
  * This file is part of Jalview.
@@ -1779,7 +1779,7 @@ public class PopupMenu extends JPopupMenu implements ColourChangeListener
     List<AlignCalcWorkerI> workers = ap.alignFrame.getViewport()
             .getCalcManager().getRegisteredWorkersOfClass(
                     SecondaryStructureConsensusThread.class);
-    if (!workers.isEmpty())
+    if (workers!=null && !workers.isEmpty())
     {
 
       ap.alignFrame.getViewport().getCalcManager()
