@@ -1,23 +1,3 @@
-/*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
- *
- * This file is part of Jalview.
- *
- * Jalview is free software: you can redistribute it and/or
- * modify it under the terms of the GNU General Public License 
- * as published by the Free Software Foundation, either version 3
- * of the License, or (at your option) any later version.
- *
- * Jalview is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty 
- * of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
- * PURPOSE.  See the GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with Jalview.  If not, see <http://www.gnu.org/licenses/>.
- * The Jalview Authors are detailed in the 'AUTHORS' file.
- */
 package jalview.gui;
 
 import java.io.File;
@@ -95,12 +75,10 @@ public class QuitHandler
 
   protected static QResponse setResponse(QResponse qresponse)
   {
-    Console.trace("setResponse(" + qresponse.toString() + ")");
     gotQuitResponse = qresponse;
     if ((qresponse == QResponse.CANCEL_QUIT || qresponse == QResponse.NULL)
             && flatlafResponse != null)
     {
-      Console.trace("Running flatLafResponse.cancelQuit()");
       flatlafResponse.cancelQuit();
     }
     return qresponse;
@@ -112,18 +90,18 @@ public class QuitHandler
   }
 
   public static final Runnable defaultCancelQuit = () -> {
-    Console.trace("QuitHandler: (default) Quit action CANCELLED by user");
+    Console.debug("QuitHandler: (default) Quit action CANCELLED by user");
     // reset
     setResponse(QResponse.CANCEL_QUIT);
   };
 
   public static final Runnable defaultOkQuit = () -> {
-    Console.trace("QuitHandler: (default) Quit action CONFIRMED by user");
+    Console.debug("QuitHandler: (default) Quit action CONFIRMED by user");
     setResponse(QResponse.QUIT);
   };
 
   public static final Runnable defaultForceQuit = () -> {
-    Console.trace("QuitHandler: (default) Quit action FORCED by user");
+    Console.debug("QuitHandler: (default) Quit action FORCED by user");
     // note that shutdown hook will not be run
     Runtime.getRuntime().halt(0);
     setResponse(QResponse.FORCE_QUIT); // this line never reached!
@@ -139,13 +117,9 @@ public class QuitHandler
           Runnable forceQuit, Runnable cancelQuit)
   {
     QResponse got = gotQuitResponse();
-    Console.trace("Quit response is '" + got.toString()
-            + "' at start of getQuitResponse(...)");
     if (got != QResponse.NULL && got != QResponse.CANCEL_QUIT)
     {
       // quit has already been selected, continue with calling quit method
-      Console.trace("Returning already set quit response of '"
-              + got.toString() + "' at start of getQuitResponse(...)");
       return got;
     }
 
@@ -167,18 +141,14 @@ public class QuitHandler
     {
       confirmQuit = jalview.bin.Cache
               .getDefault(jalview.gui.Desktop.CONFIRM_KEYBOARD_QUIT, true);
-      Console.trace("Jalview property '"
-              + jalview.gui.Desktop.CONFIRM_KEYBOARD_QUIT + "' is "
-              + confirmQuit + " -- " + (confirmQuit ? "" : "not ")
-              + "confirming quit");
+      Console.debug("Jalview property '"
+              + jalview.gui.Desktop.CONFIRM_KEYBOARD_QUIT
+              + "' is/defaults to " + confirmQuit + " -- "
+              + (confirmQuit ? "" : "not ") + "confirming quit");
     }
-
     got = confirmQuit ? QResponse.NULL : QResponse.QUIT;
     setResponse(got);
 
-    Console.trace("confirmQuit is '" + confirmQuit
-            + "', setting quit response to " + got);
-
     if (confirmQuit)
     {
       String messageString = MessageManager
@@ -199,14 +169,9 @@ public class QuitHandler
               { MessageManager.getString("action.quit"),
                   MessageManager.getString("action.cancel") },
               MessageManager.getString("action.quit"), true);
-
-      Console.trace("Waiting for response handler to run action");
-      qd.waitForHandlerToFinish();
     }
 
     got = gotQuitResponse();
-    Console.trace("Quit response is '" + got.toString()
-            + "' after response handler");
 
     // check for external viewer frames
     if (got != QResponse.CANCEL_QUIT)
@@ -260,9 +225,7 @@ public class QuitHandler
 
     got = gotQuitResponse();
 
-    Console.trace("Quit response is '" + got.toString()
-            + "' after external structure viewer check");
-
+    boolean wait = false;
     if (got == QResponse.CANCEL_QUIT)
     {
       // reset
@@ -273,21 +236,16 @@ public class QuitHandler
     }
     else if (got == QResponse.QUIT)
     {
-      Console.debug("Quit response is '" + got.toString()
-              + "' before waiting for save");
       if (Cache.getDefault("WAIT_FOR_SAVE", true)
               && BackupFiles.hasSavesInProgress())
       {
         waitQuit(interactive, okQuit, forceQuit, cancelQuit);
+        QResponse waitResponse = gotQuitResponse();
+        wait = waitResponse == QResponse.QUIT;
       }
-      Console.debug("Quit response is '" + got.toString()
-              + "' after waiting for save");
     }
 
     Runnable next = null;
-    got = gotQuitResponse();
-    Console.debug("Quit response is '" + got.toString()
-            + "' before setting next");
     switch (gotQuitResponse())
     {
     case QUIT:
@@ -300,16 +258,10 @@ public class QuitHandler
       next = cancelQuit;
       break;
     }
-    Console.debug(
-            "Quit response is '" + got.toString() + "' after setting next");
-    Console.debug("Next is '" + next + "'");
     try
     {
       executor.submit(next).get();
-      Console.debug(next + " is submitted");
       got = gotQuitResponse();
-      Console.debug("Quit response is '" + got.toString()
-              + "' after submitting next");
     } catch (RejectedExecutionException e)
     {
       // QuitHander.abortQuit() probably called
@@ -322,23 +274,16 @@ public class QuitHandler
       jalview.bin.Console
               .debug("Exception during quit handling (final choice)", e);
     }
-    Console.debug("Setting response to '" + got.toString()
-            + "' after submitting next");
     setResponse(got);
 
-    Console.debug("Checking if quit was cancelled");
     if (quitCancelled())
     {
       // reset if cancelled
       Console.debug("Quit cancelled");
       setResponse(QResponse.NULL);
-      Console.debug("Set response to " + QResponse.NULL.toString()
-              + ". Returning " + QResponse.CANCEL_QUIT);
       return QResponse.CANCEL_QUIT;
     }
-    got = gotQuitResponse();
-    Console.debug("Returning " + got.toString());
-    return got;
+    return gotQuitResponse();
   }
 
   private static QResponse waitQuit(boolean interactive, Runnable okQuit,
@@ -349,7 +294,7 @@ public class QuitHandler
       return QResponse.QUIT;
 
     int size = 0;
-    AlignFrame[] afArray = Desktop.getDesktopAlignFrames();
+    AlignFrame[] afArray = Desktop.getAlignFrames();
     if (!(afArray == null || afArray.length == 0))
     {
       for (int i = 0; i < afArray.length; i++)
