@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -35,7 +35,6 @@ import java.util.List;
 
 import javax.swing.JPanel;
 
-import jalview.api.SequenceRenderer;
 import jalview.datamodel.AlignmentI;
 import jalview.datamodel.HiddenColumns;
 import jalview.datamodel.SearchResultsI;
@@ -108,7 +107,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
   {
     this.av = ap.av;
     fr = new FeatureRenderer(ap);
-    seqRdr = new jalview.gui.SequenceRenderer(av);
+    seqRdr = new SequenceRenderer(av);
     setLayout(new BorderLayout());
     PaintRefresher.Register(this, av.getSequenceSetId());
     setBackground(Color.white);
@@ -323,7 +322,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
 
       if (vertical > 0) // scroll down
       {
-        startSeq = endSeq - vertical + 1;
+        startSeq = endSeq - vertical;
 
         if (startSeq < ranges.getStartSeq())
         { // ie scrolling too fast, more than a page at a time
@@ -331,12 +330,12 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
         }
         else
         {
-          transY = img.getHeight() - (vertical * charHeight);
+          transY = img.getHeight() - ((vertical + 1) * charHeight);
         }
       }
-      else if (vertical < 0) // scroll up
+      else if (vertical < 0)
       {
-        endSeq = startSeq - vertical - 1;
+        endSeq = startSeq - vertical;
 
         if (endSeq > ranges.getEndSeq())
         {
@@ -344,8 +343,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
         }
       }
 
-      // jalview.bin.Console.errPrintln(">>> FastPaint to " + transX + " " +
-      // transY + " "
+      // System.err.println(">>> FastPaint to " + transX + " " + transY + " "
       // + horizontal + " " + vertical + " " + startRes + " " + endRes
       // + " " + startSeq + " " + endSeq);
 
@@ -357,15 +355,14 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
       /** @j2sNative xxi = this.img */
 
       gg.translate(transX, transY);
-      drawPanel(seqRdr, gg, startRes, endRes, startSeq, endSeq, 0);
+      drawPanel(gg, startRes, endRes, startSeq, endSeq, 0);
       gg.translate(-transX, -transY);
       gg.dispose();
 
       // Call repaint on alignment panel so that repaints from other alignment
       // panel components can be aggregated. Otherwise performance of the
       // overview window and others may be adversely affected.
-      // jalview.bin.Console.outPrintln("SeqCanvas fastPaint() repaint()
-      // request...");
+      // System.out.println("SeqCanvas fastPaint() repaint() request...");
       av.getAlignPanel().repaint();
     } finally
     {
@@ -458,12 +455,11 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
 
       if (av.getWrapAlignment())
       {
-        drawWrappedPanel(seqRdr, gg, getWidth(), getHeight(),
-                ranges.getStartRes());
+        drawWrappedPanel(gg, getWidth(), getHeight(), ranges.getStartRes());
       }
       else
       {
-        drawPanel(seqRdr, gg, startRes, endRes, startSeq, endSeq, 0);
+        drawPanel(gg, startRes, endRes, startSeq, endSeq, 0);
       }
 
       drawSelectionGroup(gg, startRes, endRes, startSeq, endSeq);
@@ -495,8 +491,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
   public void drawPanelForPrinting(Graphics g1, int startRes, int endRes,
           int startSeq, int endSeq)
   {
-    SequenceRenderer localSeqR = new jalview.gui.SequenceRenderer(av);
-    drawPanel(localSeqR, g1, startRes, endRes, startSeq, endSeq, 0);
+    drawPanel(g1, startRes, endRes, startSeq, endSeq, 0);
 
     drawSelectionGroup((Graphics2D) g1, startRes, endRes, startSeq, endSeq);
   }
@@ -516,8 +511,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
   public void drawWrappedPanelForPrinting(Graphics g, int canvasWidth,
           int canvasHeight, int startRes)
   {
-    SequenceRenderer localSeqR = new jalview.gui.SequenceRenderer(av);
-    drawWrappedPanel(localSeqR, g, canvasWidth, canvasHeight, startRes);
+    drawWrappedPanel(g, canvasWidth, canvasHeight, startRes);
 
     SequenceGroup group = av.getSelectionGroup();
     if (group != null)
@@ -556,20 +550,6 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
     return (canvasWidth - labelWidthEast - labelWidthWest) / charWidth;
   }
 
-  public int getMinimumWrappedCanvasWidth()
-  {
-    int charWidth = av.getCharWidth();
-    FontMetrics fm = getFontMetrics(av.getFont());
-    int labelWidth = 0;
-    if (av.getScaleRightWrapped() || av.getScaleLeftWrapped())
-    {
-      labelWidth = getLabelWidth(fm);
-    }
-    labelWidthEast = av.getScaleRightWrapped() ? labelWidth : 0;
-    labelWidthWest = av.getScaleLeftWrapped() ? labelWidth : 0;
-    return labelWidthEast + labelWidthWest + charWidth;
-  }
-
   /**
    * Returns a pixel width sufficient to show the largest sequence coordinate
    * (end position) in the alignment, calculated as the FontMetrics width of
@@ -614,8 +594,8 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
    * @param startColumn
    *          the first column (0...) of the alignment to draw
    */
-  public void drawWrappedPanel(SequenceRenderer seqRdr, Graphics g,
-          int canvasWidth, int canvasHeight, final int startColumn)
+  public void drawWrappedPanel(Graphics g, int canvasWidth,
+          int canvasHeight, final int startColumn)
   {
     int wrappedWidthInResidues = calculateWrappedGeometry(canvasWidth,
             canvasHeight);
@@ -643,7 +623,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
     {
       int endColumn = Math.min(maxWidth,
               start + wrappedWidthInResidues - 1);
-      drawWrappedWidth(seqRdr, g, ypos, start, endColumn, canvasHeight);
+      drawWrappedWidth(g, ypos, start, endColumn, canvasHeight);
       ypos += wrappedRepeatHeightPx;
       start += wrappedWidthInResidues;
       currentWidth++;
@@ -736,8 +716,8 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
    * @param endColumn
    * @param canvasHeight
    */
-  protected void drawWrappedWidth(SequenceRenderer seqRdr, Graphics g,
-          final int ypos, final int startColumn, final int endColumn,
+  protected void drawWrappedWidth(Graphics g, final int ypos,
+          final int startColumn, final int endColumn,
           final int canvasHeight)
   {
     ViewportRanges ranges = av.getRanges();
@@ -765,8 +745,8 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
     g.fillRect(0, ypos, (endx - startColumn + 1) * charWidth,
             wrappedRepeatHeightPx);
 
-    drawPanel(seqRdr, g, startColumn, endx, 0,
-            av.getAlignment().getHeight() - 1, ypos);
+    drawPanel(g, startColumn, endx, 0, av.getAlignment().getHeight() - 1,
+            ypos);
 
     int cHeight = av.getAlignment().getHeight() * av.getCharHeight();
 
@@ -970,10 +950,6 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
    * between the markers is drawn separately, followed by the hidden column
    * marker.
    * 
-   * @param localSeqR
-   *          - sequence renderer implementation - when null, uses the one used
-   *          for rendering interactive GUI
-   * 
    * @param g1
    *          the graphics context, positioned at the first residue to be drawn
    * @param startRes
@@ -987,20 +963,15 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
    * @param yOffset
    *          vertical offset at which to draw (for wrapped alignments)
    */
-  public void drawPanel(SequenceRenderer localSeqR, Graphics g1,
-          final int startRes, final int endRes, final int startSeq,
-          final int endSeq, final int yOffset)
+  public void drawPanel(Graphics g1, final int startRes, final int endRes,
+          final int startSeq, final int endSeq, final int yOffset)
   {
     int charHeight = av.getCharHeight();
     int charWidth = av.getCharWidth();
 
-    if (localSeqR == null)
-    {
-      localSeqR = seqRdr;
-    }
     if (!av.hasHiddenColumns())
     {
-      draw(localSeqR, g1, startRes, endRes, startSeq, endSeq, yOffset);
+      draw(g1, startRes, endRes, startSeq, endSeq, yOffset);
     }
     else
     {
@@ -1024,8 +995,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
          */
         g1.translate(screenY * charWidth, 0);
 
-        draw(localSeqR, g1, blockStart, blockEnd, startSeq, endSeq,
-                yOffset);
+        draw(g1, blockStart, blockEnd, startSeq, endSeq, yOffset);
 
         /*
          * draw the downline of the hidden column marker (ScalePanel draws the
@@ -1051,8 +1021,6 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
   /**
    * Draws a region of the visible alignment
    * 
-   * @param seqRdr
-   * 
    * @param g1
    * @param startRes
    *          offset of the first column in the visible region (0..)
@@ -1065,8 +1033,8 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
    * @param yOffset
    *          vertical offset at which to draw (for wrapped alignments)
    */
-  private void draw(SequenceRenderer seqRdr, Graphics g, int startRes,
-          int endRes, int startSeq, int endSeq, int offset)
+  private void draw(Graphics g, int startRes, int endRes, int startSeq,
+          int endSeq, int offset)
   {
     int charHeight = av.getCharHeight();
     int charWidth = av.getCharWidth();
@@ -1407,7 +1375,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
         }
         else if (inGroup)
         {
-          drawVerticals(g, sx, xwidth, visWidth, oldY, bottom);
+          drawVerticals(g, sx, xwidth, visWidth, oldY, sy);
           drawHorizontals(g, sx, xwidth, visWidth, top, bottom);
 
           // reset top and bottom
@@ -1419,8 +1387,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
       if (inGroup)
       {
         sy = verticalOffset + ((i - startSeq) * charHeight);
-        drawVerticals(g, sx, xwidth, visWidth, oldY,
-                bottom == -1 ? sy : bottom);
+        drawVerticals(g, sx, xwidth, visWidth, oldY, sy);
         drawHorizontals(g, sx, xwidth, visWidth, top, bottom);
       }
     }
@@ -1495,14 +1462,14 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
     // group
     if (sx >= 0 && sx < visWidth)
     {
-      g.drawLine(sx, oldY, sx, sy - 1);
+      g.drawLine(sx, oldY, sx, sy);
     }
 
     // if end position is visible, draw vertical line to right of
     // group
     if (sx + xwidth < visWidth)
     {
-      g.drawLine(sx + xwidth, oldY, sx + xwidth, sy - 1);
+      g.drawLine(sx + xwidth, oldY, sx + xwidth, sy);
     }
   }
 
@@ -1686,7 +1653,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
       int transY = (firstSeq - ranges.getStartSeq()) * av.getCharHeight();
       Graphics gg = img.getGraphics();
       gg.translate(transX, transY);
-      drawPanel(seqRdr, gg, firstCol, lastCol, firstSeq, lastSeq, 0);
+      drawPanel(gg, firstCol, lastCol, firstSeq, lastSeq, 0);
       gg.translate(-transX, -transY);
       gg.dispose();
     }
@@ -1698,8 +1665,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
   public void propertyChange(PropertyChangeEvent evt)
   {
     String eventName = evt.getPropertyName();
-    // jalview.bin.Console.errPrintln(">>SeqCanvas propertyChange " +
-    // eventName);
+    // System.err.println(">>SeqCanvas propertyChange " + eventName);
     if (eventName.equals(SequenceGroup.SEQ_GROUP_CHANGED))
     {
       fastPaint = true;
@@ -1709,8 +1675,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
     else if (eventName.equals(ViewportRanges.MOVE_VIEWPORT))
     {
       fastPaint = false;
-      // jalview.bin.Console.errPrintln("!!!! fastPaint false from
-      // MOVE_VIEWPORT");
+      // System.err.println("!!!! fastPaint false from MOVE_VIEWPORT");
       repaint();
       return;
     }
@@ -1840,7 +1805,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
       if (scrollX < 0)
       {
         int startRes = ranges.getStartRes();
-        drawWrappedWidth(seqRdr, gg, wrappedSpaceAboveAlignment, startRes,
+        drawWrappedWidth(gg, wrappedSpaceAboveAlignment, startRes,
                 startRes - scrollX - 1, getHeight());
       }
       else
@@ -1914,7 +1879,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
               wrappedRepeatHeightPx);
       gg.translate(-xOffset, 0);
 
-      drawWrappedWidth(seqRdr, gg, ypos, startRes, endRes, canvasHeight);
+      drawWrappedWidth(gg, ypos, startRes, endRes, canvasHeight);
 
     }
 
@@ -1947,7 +1912,7 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
 
     if (startRes < ranges.getVisibleAlignmentWidth())
     {
-      drawWrappedWidth(seqRdr, gg, ypos, startRes, endRes, canvasHeight);
+      drawWrappedWidth(gg, ypos, startRes, endRes, canvasHeight);
     }
 
     /*
@@ -2168,8 +2133,8 @@ public class SeqCanvas extends JPanel implements ViewportListenerI
               {
                 matchFound = true;
                 gg.translate(transX, transY);
-                drawPanel(seqRdr, gg, displayColumn, displayColumn, seqNo,
-                        seqNo, yOffset);
+                drawPanel(gg, displayColumn, displayColumn, seqNo, seqNo,
+                        yOffset);
                 gg.translate(-transX, -transY);
               }
             }
