@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -145,7 +145,7 @@ public class TreeCanvas extends JPanel implements MouseListener, Runnable,
     scrollPane = scroller;
     addMouseListener(this);
     addMouseMotionListener(this);
-
+    
     ToolTipManager.sharedInstance().registerComponent(this);
   }
 
@@ -182,7 +182,6 @@ public class TreeCanvas extends JPanel implements MouseListener, Runnable,
     PaintRefresher.Refresh(tp, av.getSequenceSetId());
     repaint();
   }
-
   /**
    * DOCUMENT ME!
    * 
@@ -225,12 +224,12 @@ public class TreeCanvas extends JPanel implements MouseListener, Runnable,
     longestName = "";
 
     AlignmentAnnotation aa = tp.getAssocAnnotation();
-    ContactMatrixI cm = (aa != null) ? av.getContactMatrix(aa) : null;
-    if (cm != null && cm.hasCutHeight())
+    ContactMatrixI cm = (aa!=null) ? av.getContactMatrix(aa) : null;
+    if (cm!=null && cm.hasCutHeight())
     {
-      threshold = (float) cm.getCutHeight();
+      threshold=(float) cm.getCutHeight();
     }
-
+    
     for (int i = 0; i < leaves.size(); i++)
     {
       BinaryNode lf = leaves.elementAt(i);
@@ -246,17 +245,13 @@ public class TreeCanvas extends JPanel implements MouseListener, Runnable,
         longestName = TreeCanvas.PLACEHOLDER
                 + ((Sequence) lf.element()).getName();
       }
-      if (tp.isColumnWise() && cm != null)
+      if (tp.isColumnWise() && cm!=null)
       {
         // get color from group colours, if they are set for the matrix
-        try
-        {
+        try {
           Color col = cm.getGroupColorForPosition(parseColumnNode(lf));
-          setColor(lf, col.brighter());
-        } catch (NumberFormatException ex)
-        {
-        }
-        ;
+          setColor(lf,col.brighter());
+        } catch (NumberFormatException ex) {};
       }
     }
 
@@ -411,9 +406,9 @@ public class TreeCanvas extends JPanel implements MouseListener, Runnable,
       }
 
       int ystart = (node.left() == null ? 0
-              : (int) (node.left().ycount * chunk)) + offy;
+              : (int) (((BinaryNode) node.left()).ycount * chunk)) + offy;
       int yend = (node.right() == null ? 0
-              : (int) (node.right().ycount * chunk)) + offy;
+              : (int) (((BinaryNode) node.right()).ycount * chunk)) + offy;
 
       Rectangle pos = new Rectangle(xend - 2, ypos - 2, 5, 5);
       nodeHash.put(node, pos);
@@ -796,10 +791,11 @@ public class TreeCanvas extends JPanel implements MouseListener, Runnable,
 
     if (top.count == 0)
     {
-      top.count = top.left().count + top.right().count;
+      top.count = ((BinaryNode) top.left()).count
+              + ((BinaryNode) top.right()).count;
     }
 
-    float chunk = (float) (height - (offy)) / top.count;
+    double chunk = (double) (height - (offy)) / (double)top.count;
 
     drawNode(g2, tree.getTopNode(), chunk, wscale, width, offx, offy);
 
@@ -885,7 +881,7 @@ public class TreeCanvas extends JPanel implements MouseListener, Runnable,
       Vector<BinaryNode> leaves = tree.findLeaves(highlightNode);
       if (tp.isColumnWise())
       {
-        markColumnsFor(getAssociatedPanels(), leaves, Color.red, false);
+        markColumnsFor(getAssociatedPanels(), leaves, Color.red,false);
       }
       else
       {
@@ -1062,7 +1058,7 @@ public class TreeCanvas extends JPanel implements MouseListener, Runnable,
     for (int i = 0; i < groups.size(); i++)
     {
       Color col = ColorUtils.getARandomColor();
-
+      
       setColor(groups.get(i), col.brighter());
 
       Vector<BinaryNode> l = tree.findLeaves(groups.get(i));
@@ -1110,13 +1106,11 @@ public class TreeCanvas extends JPanel implements MouseListener, Runnable,
       }
     }
   }
-
   private int parseColumnNode(BinaryNode bn) throws NumberFormatException
   {
     return Integer.parseInt(
             bn.getName().substring(bn.getName().indexOf("c") + 1));
   }
-
   private boolean isColumnForNodeSelected(BinaryNode bn)
   {
     SequenceI rseq = tp.assocAnnotation.sequenceRef;
@@ -1136,17 +1130,16 @@ public class TreeCanvas extends JPanel implements MouseListener, Runnable,
     ColumnSelection cs = av.getColumnSelection();
     HiddenColumns hc = av.getAlignment().getHiddenColumns();
     AlignmentAnnotation aa = tp.getAssocAnnotation();
-    int offp = -1;
+    int offp=-1;
     if (aa != null)
     {
       ContactMatrixI cm = av.getContactMatrix(aa);
-      // generally, we assume cm has 1:1 mapping to annotation row - probably
-      // wrong
+      // generally, we assume cm has 1:1 mapping to annotation row - probably wrong
       // but.. if
       if (cm instanceof MappableContactMatrixI)
       {
         int[] pos;
-        // use the mappable's mapping - always the case for PAE Matrices so good
+          // use the mappable's mapping - always the case for PAE Matrices so good
         // for 2.11.3
         MappableContactMatrixI mcm = (MappableContactMatrixI) cm;
         pos = mcm.getMappedPositionsFor(rseq, colm + 1);
@@ -1155,18 +1148,16 @@ public class TreeCanvas extends JPanel implements MouseListener, Runnable,
         {
           offp = rseq.findIndex(pos[0]);
         }
-      }
-      else
-      {
+      } else {
         offp = colm;
       }
     }
-    if (offp <= 0)
+    if (offp<=0)
     {
       return false;
     }
 
-    offp -= 2;
+    offp-=2;
     if (!av.hasHiddenColumns())
     {
       return cs.contains(offp);
@@ -1178,7 +1169,6 @@ public class TreeCanvas extends JPanel implements MouseListener, Runnable,
     }
     return false;
   }
-
   private BitSet createColumnGroupFor(Vector<BinaryNode> l, Color col)
   {
     BitSet gp = new BitSet();
@@ -1236,16 +1226,17 @@ public class TreeCanvas extends JPanel implements MouseListener, Runnable,
       {
         continue;
       }
-      if (mcm != null)
+      if (mcm!=null)
       {
-        int[] seqpos = mcm.getMappedPositionsFor(rseq, colm);
+        int[] seqpos = mcm.getMappedPositionsFor(
+                rseq, colm);
         if (seqpos == null)
         {
           // no mapping for this column.
           continue;
         }
         // TODO: handle ranges...
-        offp = rseq.findIndex(seqpos[0]) - 1;
+        offp = rseq.findIndex(seqpos[0])-1;
       }
       else
       {
