@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -310,7 +310,7 @@ public class ThreeDBStructureChooserQuerySource
             && tdBeaconsFilters.contains(fieldToFilterBy);
   }
 
-  protected String remove_prefix(String fieldToFilterBy)
+  private String remove_prefix(String fieldToFilterBy)
   {
     if (tdBeaconsFilters != null
             && tdBeaconsFilters.contains(fieldToFilterBy)
@@ -387,8 +387,6 @@ public class ThreeDBStructureChooserQuerySource
     int typeColumnIndex = restable.getColumn("Provider").getModelIndex();
     int humanUrl = restable.getColumn("Page URL").getModelIndex();
     int modelformat = restable.getColumn("Model Format").getModelIndex();
-    int idx_mcat = restable.getColumn("Model Category").getModelIndex();
-
     final int up_start_idx = restable.getColumn("Uniprot Start")
             .getModelIndex();
     final int up_end_idx = restable.getColumn("Uniprot End")
@@ -425,10 +423,6 @@ public class ThreeDBStructureChooserQuerySource
               .toString();
       String modelPage = humanUrl < 1 ? null
               : (String) restable.getValueAt(row, humanUrl);
-
-      String modelCategory = idx_mcat < 1 ? null
-              : (String) restable.getValueAt(row, idx_mcat);
-
       String strucFormat = restable.getValueAt(row, modelformat).toString();
 
       SequenceI selectedSeq = (SequenceI) restable.getValueAt(row,
@@ -463,7 +457,6 @@ public class ThreeDBStructureChooserQuerySource
         {
           pdbEntry.setProviderPage(modelPage);
         }
-        pdbEntry.setProviderCategory(modelCategory);
         selectedSeq.getDatasetSequence().addPDBId(pdbEntry);
       }
       pdbEntriesToView[count++] = pdbEntry;
@@ -594,7 +587,7 @@ public class ThreeDBStructureChooserQuerySource
       {
         if (!hasPdbResp)
         {
-          jalview.bin.Console.outPrintln(
+          System.out.println(
                   "Warning: seems like we couldn't get to the PDBe search interface.");
         }
         else
