@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -188,7 +188,7 @@ public class PhylipFile extends AlignFile
 
     } catch (IOException e)
     {
-      jalview.bin.Console.errPrintln("Exception parsing PHYLIP file " + e);
+      System.err.println("Exception parsing PHYLIP file " + e);
       e.printStackTrace(System.err);
       throw e;
     }
