@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -114,9 +114,8 @@ public abstract class GffHelperBase implements GffHelperI
      */
     if (!trimMapping(from, to, fromRatio, toRatio))
     {
-      jalview.bin.Console.errPrintln(
-              "Ignoring mapping from " + Arrays.toString(from) + " to "
-                      + Arrays.toString(to) + " as counts don't match!");
+      System.err.println("Ignoring mapping from " + Arrays.toString(from)
+              + " to " + Arrays.toString(to) + " as counts don't match!");
       return null;
     }
 
@@ -167,7 +166,7 @@ public abstract class GffHelperBase implements GffHelperI
       {
         from[1] += fromOverlap / toRatio;
       }
-      jalview.bin.Console.errPrintln(Arrays.toString(from));
+      System.err.println(Arrays.toString(from));
       return true;
     }
     else if (fromOverlap < 0 && fromOverlap % fromRatio == 0)
@@ -186,7 +185,7 @@ public abstract class GffHelperBase implements GffHelperI
       {
         to[1] += fromOverlap / fromRatio;
       }
-      jalview.bin.Console.errPrintln(Arrays.toString(to));
+      System.err.println(Arrays.toString(to));
       return true;
     }
 
@@ -445,8 +444,7 @@ public abstract class GffHelperBase implements GffHelperI
       return sf;
     } catch (NumberFormatException nfe)
     {
-      jalview.bin.Console
-              .errPrintln("Invalid number in gff: " + nfe.getMessage());
+      System.err.println("Invalid number in gff: " + nfe.getMessage());
       return null;
     }
   }
@@ -506,7 +504,7 @@ public abstract class GffHelperBase implements GffHelperI
 
     if (!valid)
     {
-      jalview.bin.Console.errPrintln(INVALID_GFF_ATTRIBUTE_FORMAT + s);
+      System.err.println(INVALID_GFF_ATTRIBUTE_FORMAT + s);
       return map;
     }
 
@@ -528,7 +526,7 @@ public abstract class GffHelperBase implements GffHelperI
       theKey = theKey.trim();
       if (theKey.isEmpty())
       {
-        jalview.bin.Console.errPrintln(INVALID_GFF_ATTRIBUTE_FORMAT + s);
+        System.err.println(INVALID_GFF_ATTRIBUTE_FORMAT + s);
         map.clear();
         return map;
       }
