@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -123,12 +123,12 @@ public class Matrix implements MatrixI
       if (row != null)
       {
         value[i] = new double[row.length];
-        int j = 0;
-        for (float oldValue : row)
-        {
-          value[i][j] = oldValue;
-          j++;
-        }
+	int j = 0;
+	for (float oldValue : row)
+	{
+	  value[i][j] = oldValue;
+	  j++;
+	}
       }
       i++;
     }
@@ -191,11 +191,10 @@ public class Matrix implements MatrixI
          */
         for (int k = 0; k < in.width(); k++)
         {
-          if (!Double.isNaN(in.getValue(i, k))
-                  && !Double.isNaN(this.value[k][j]))
-          {
+	  if (!Double.isNaN(in.getValue(i,k)) && !Double.isNaN(this.value[k][j]))
+	  {
             tmp[i][j] += (in.getValue(i, k) * this.value[k][j]);
-          }
+	  }
         }
       }
     }
@@ -495,7 +494,7 @@ public class Matrix implements MatrixI
           }
           else
           {
-            // jalview.bin.Console.outPrintln("Iteration " + iter);
+            // System.out.println("Iteration " + iter);
           }
 
           g = (d[l] - d[l - 1]) / (2.0 * e[l - 1]);
@@ -759,7 +758,7 @@ public class Matrix implements MatrixI
           }
           else
           {
-            // jalview.bin.Console.outPrintln("Iteration " + iter);
+            // System.out.println("Iteration " + iter);
           }
 
           g = (d[l] - d[l - 1]) / (2.0 * e[l - 1]);
@@ -834,10 +833,10 @@ public class Matrix implements MatrixI
   }
 
   /**
-   * returns the matrix as a double[][] array
-   *
-   * @return
-   */
+  * returns the matrix as a double[][] array
+  *
+  * @return
+  */
   @Override
   public double[][] asArray()
   {
@@ -1019,8 +1018,7 @@ public class Matrix implements MatrixI
   /**
    * Add d to all entries of this matrix
    * 
-   * @param d
-   *          ~ value to add
+   * @param d ~ value to add
    */
   @Override
   public void add(double d)
@@ -1088,7 +1086,7 @@ public class Matrix implements MatrixI
   }
 
   /**
-   * Returns a copy in which every value in the matrix is its absolute
+   * Returns a copy in which  every value in the matrix is its absolute
    * 
    * @return
    */
@@ -1124,7 +1122,7 @@ public class Matrix implements MatrixI
     {
       if (row != null)
       {
-        mean[i++] = MiscMath.mean(row);
+	mean[i++] = MiscMath.mean(row);
       }
     }
     return mean;
@@ -1144,17 +1142,17 @@ public class Matrix implements MatrixI
       double[] column = getColumn(j);
       if (column != null)
       {
-        mean[j] = MiscMath.mean(column);
+	mean[j] = MiscMath.mean(column);
       }
     }
     return mean;
   }
 
   /**
-   * return a flattened matrix containing the sum of each column
-   *
-   * @return
-   */
+  * return a flattened matrix containing the sum of each column
+  *
+  * @return
+  */
   @Override
   public double[] sumCol()
   {
@@ -1164,17 +1162,17 @@ public class Matrix implements MatrixI
       double[] column = getColumn(j);
       if (column != null)
       {
-        sum[j] = MiscMath.sum(column);
+	sum[j] = MiscMath.sum(column);
       }
-    }
+    } 
     return sum;
   }
 
   /**
-   * returns the mean value of the complete matrix
-   *
-   * @return
-   */
+  * returns the mean value of the complete matrix
+  *
+  * @return
+  */
   @Override
   public double mean()
   {
@@ -1184,51 +1182,47 @@ public class Matrix implements MatrixI
     {
       for (double col : row)
       {
-        if (!Double.isNaN(col))
-        {
-          sum += col;
-        }
-        else
-        {
-          nanCount++;
-        }
+	if (!Double.isNaN(col))
+	{
+	  sum += col;
+	} else {
+	  nanCount++;
+	}
       }
     }
     return sum / (double) (this.rows * this.cols - nanCount);
   }
 
   /**
-   * fills up a diagonal matrix with its transposed copy !other side should be
-   * filled with 0 !keeps Double.NaN found in either side
-   *
-   * TODO check on which side it was diagonal and only do calculations for the
-   * other side
-   */
+  * fills up a diagonal matrix with its transposed copy
+  * !other side should be filled with 0
+  * !keeps Double.NaN found in either side
+  *
+  * TODO check on which side it was diagonal and only do calculations for the other side
+  */
   @Override
   public void fillDiagonal()
   {
     int n = this.rows;
     int m = this.cols;
-    MatrixI copy = this.transpose(); // goes through each element in the matrix
-                                     // and
-    for (int i = 0; i < n; i++) // adds the value in the transposed copy to the
-                                // original value
+    MatrixI copy = this.transpose();	// goes through each element in the matrix and
+    for (int i = 0; i < n; i++)		// adds the value in the transposed copy to the original value
     {
       for (int j = 0; j < m; j++)
       {
-        if (i != j)
-        {
-          this.addValue(i, j, copy.getValue(i, j));
-        }
+	if (i != j)
+	{
+	  this.addValue(i, j, copy.getValue(i,j));
+	}
       }
     }
   }
 
   /**
-   * counts the number of Double.NaN in the matrix
-   *
-   * @return
-   */
+  * counts the number of Double.NaN in the matrix
+  *
+  * @return
+  */
   @Override
   public int countNaN()
   {
@@ -1237,139 +1231,117 @@ public class Matrix implements MatrixI
     {
       for (int j = 0; j < this.cols; j++)
       {
-        if (Double.isNaN(this.getValue(i, j)))
-        {
-          NaN++;
-        }
+	if (Double.isNaN(this.getValue(i,j)))
+ 	{
+	  NaN++;
+	}
       }
     }
     return NaN;
   }
 
   /**
-   * performs an element-wise addition of this matrix by another matrix ~ this -
-   * m
-   * 
-   * @param m
-   *          ~ other matrix
-   *
-   * @return
-   */
+  * performs an element-wise addition of this matrix by another matrix ~ this - m
+  * @param m ~ other matrix
+  *
+  * @return
+  */
   @Override
   public MatrixI add(MatrixI m)
   {
     if (m.width() != cols || m.height() != rows)
     {
-      throw new IllegalArgumentException(
-              "Can't add a " + m.height() + "x" + m.width() + " to a "
-                      + this.rows + "x" + this.cols + " matrix");
+      throw new IllegalArgumentException("Can't add a " + m.height() + "x" + m.width() + " to a " + this.rows + "x" + this.cols + " matrix");
     }
     double[][] tmp = new double[this.rows][this.cols];
     for (int i = 0; i < this.rows; i++)
     {
       for (int j = 0; j < this.cols; j++)
       {
-        tmp[i][j] = this.getValue(i, j) + m.getValue(i, j);
+	tmp[i][j] = this.getValue(i,j) + m.getValue(i,j);
       }
     }
     return new Matrix(tmp);
   }
 
   /**
-   * performs an element-wise subtraction of this matrix by another matrix ~
-   * this - m
-   * 
-   * @param m
-   *          ~ other matrix
-   *
-   * @return
-   */
+  * performs an element-wise subtraction of this matrix by another matrix ~ this - m
+  * @param m ~ other matrix
+  *
+  * @return
+  */
   @Override
   public MatrixI subtract(MatrixI m)
   {
     if (m.width() != cols || m.height() != rows)
     {
-      throw new IllegalArgumentException("Can't subtract a " + m.height()
-              + "x" + m.width() + " from a " + this.rows + "x" + this.cols
-              + " matrix");
+      throw new IllegalArgumentException("Can't subtract a " + m.height() + "x" + m.width() + " from a " + this.rows + "x" + this.cols + " matrix");
     }
     double[][] tmp = new double[this.rows][this.cols];
     for (int i = 0; i < this.rows; i++)
     {
       for (int j = 0; j < this.cols; j++)
       {
-        tmp[i][j] = this.getValue(i, j) - m.getValue(i, j);
+	tmp[i][j] = this.getValue(i,j) -  m.getValue(i,j);
       }
     }
     return new Matrix(tmp);
   }
 
   /**
-   * performs an element-wise multiplication of this matrix by another matrix ~
-   * this * m
-   * 
-   * @param m
-   *          ~ other matrix
-   *
-   * @return
-   */
+  * performs an element-wise multiplication of this matrix by another matrix ~ this * m
+  * @param m ~ other matrix
+  *
+  * @return
+  */
   @Override
   public MatrixI elementwiseMultiply(MatrixI m)
   {
     if (m.width() != cols || m.height() != rows)
     {
-      throw new IllegalArgumentException(
-              "Can't multiply a " + this.rows + "x" + this.cols + " by a "
-                      + m.height() + "x" + m.width() + " matrix");
+      throw new IllegalArgumentException("Can't multiply a " + this.rows + "x" + this.cols + " by a " + m.height() + "x" + m.width() + " matrix");
     }
     double[][] tmp = new double[this.rows][this.cols];
     for (int i = 0; i < this.rows; i++)
     {
       for (int j = 0; j < this.cols; j++)
       {
-        tmp[i][j] = this.getValue(i, j) * m.getValue(i, j);
+        tmp[i][j] = this.getValue(i, j) * m.getValue(i,j);
       }
     }
     return new Matrix(tmp);
   }
 
   /**
-   * performs an element-wise division of this matrix by another matrix ~ this /
-   * m
-   * 
-   * @param m
-   *          ~ other matrix
-   *
-   * @return
-   */
+  * performs an element-wise division of this matrix by another matrix ~ this / m
+  * @param m ~ other matrix
+  *
+  * @return
+  */
   @Override
   public MatrixI elementwiseDivide(MatrixI m)
   {
     if (m.width() != cols || m.height() != rows)
     {
-      throw new IllegalArgumentException(
-              "Can't divide a " + this.rows + "x" + this.cols + " by a "
-                      + m.height() + "x" + m.width() + " matrix");
+      throw new IllegalArgumentException("Can't divide a " + this.rows + "x" + this.cols + " by a " + m.height() + "x" + m.width() + " matrix");
     }
     double[][] tmp = new double[this.rows][this.cols];
     for (int i = 0; i < this.rows; i++)
     {
       for (int j = 0; j < this.cols; j++)
       {
-        tmp[i][j] = this.getValue(i, j) / m.getValue(i, j);
+        tmp[i][j] = this.getValue(i, j) / m.getValue(i,j);
       }
     }
     return new Matrix(tmp);
   }
 
   /**
-   * calculate the root-mean-square for tow matrices
-   * 
-   * @param m
-   *          ~ other matrix
-   *
-   * @return
-   */
+  * calculate the root-mean-square for tow matrices
+  * @param m ~ other matrix
+  *
+  * @return
+  */
   @Override
   public double rmsd(MatrixI m)
   {
@@ -1379,10 +1351,10 @@ public class Matrix implements MatrixI
   }
 
   /**
-   * calculates the Frobenius norm of this matrix
-   *
-   * @return
-   */
+  * calculates the Frobenius norm of this matrix
+  *
+  * @return
+  */
   @Override
   public double norm()
   {
@@ -1391,17 +1363,17 @@ public class Matrix implements MatrixI
     {
       for (double val : row)
       {
-        result += Math.pow(val, 2);
+	result += Math.pow(val, 2);
       }
     }
     return Math.sqrt(result);
   }
 
   /**
-   * returns the sum of all values in this matrix
-   *
-   * @return
-   */
+  * returns the sum of all values in this matrix
+  *
+  * @return
+  */
   @Override
   public double sum()
   {
@@ -1410,28 +1382,24 @@ public class Matrix implements MatrixI
     {
       for (double val : row)
       {
-        sum += (Double.isNaN(val)) ? 0.0 : val;
+	sum += (Double.isNaN(val)) ? 0.0 : val;
       }
     }
     return sum;
   }
 
   /**
-   * returns the sum-product of this matrix with vector v
-   * 
-   * @param v
-   *          ~ vector
-   *
-   * @return
-   */
+  * returns the sum-product of this matrix with vector v
+  * @param v ~ vector
+  *
+  * @return
+  */
   @Override
   public double[] sumProduct(double[] v)
   {
     if (v.length != cols)
     {
-      throw new IllegalArgumentException(
-              "Vector and matrix do not have the same dimension! ("
-                      + v.length + " != " + cols + ")");
+      throw new IllegalArgumentException("Vector and matrix do not have the same dimension! (" + v.length + " != " + cols + ")");
     }
     double[] result = new double[rows];
     for (int i = 0; i < rows; i++)
@@ -1440,36 +1408,11 @@ public class Matrix implements MatrixI
       double sum = 0;
       for (int j = 0; j < row.length; j++)
       {
-        sum += row[j] * v[j];
+	sum += row[j] * v[j];
       }
       result[i] = sum;
     }
     return result;
   }
 
-  /**
-   * mirrors columns of the matrix
-   *
-   * @return
-   */
-  @Override
-  public MatrixI mirrorCol()
-  {
-    double[][] result = new double[rows][cols];
-    for (int i = 0; i < rows; i++)
-    {
-      int k = cols - 1; // reverse col
-      for (int j = 0; j < cols; j++)
-      {
-        result[i][k--] = this.getValue(i, j);
-      }
-    }
-    MatrixI resultMatrix = new Matrix(result);
-    if (d != null)
-      resultMatrix.setD(d);
-    if (e != null)
-      resultMatrix.setE(e);
-
-    return resultMatrix;
-  }
 }
