@@ -1,27 +1,11 @@
-/*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+/**
  * 
- * This file is part of Jalview.
- * 
- * Jalview is free software: you can redistribute it and/or
- * modify it under the terms of the GNU General Public License 
- * as published by the Free Software Foundation, either version 3
- * of the License, or (at your option) any later version.
- *  
- * Jalview is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty 
- * of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
- * PURPOSE.  See the GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with Jalview.  If not, see <http://www.gnu.org/licenses/>.
- * The Jalview Authors are detailed in the 'AUTHORS' file.
  */
 package jalview.renderer;
 
 import java.awt.Color;
 import java.awt.Graphics;
+import java.util.Iterator;
 
 import jalview.api.AlignViewportI;
 import jalview.datamodel.AlignmentAnnotation;
@@ -51,12 +35,10 @@ public abstract class ContactMapRenderer implements AnnotationRowRendererI
      * shown when no data available from map
      */
     Color no_data;
-
     /**
      * shown for region not currently visible - should normally not see this
      */
     Color hidden;
-
     /**
      * linear shading scheme min/max
      */
@@ -67,21 +49,6 @@ public abstract class ContactMapRenderer implements AnnotationRowRendererI
      */
     Color selMinColor, selMaxColor;
 
-    /**
-     * 
-     * @param no_data
-     *          - colour when no data available
-     * @param hidden
-     *          - colour if this row is hidden
-     * @param maxColor
-     *          - colour for maximum value of contact
-     * @param minColor
-     *          - colour for minimum value of contact
-     * @param selMinColor
-     *          - min colour if the contact has been selected
-     * @param selMaxColor
-     *          - max colour if contact is selected
-     */
     public Shading(Color no_data, Color hidden, Color maxColor,
             Color minColor, Color selMinColor, Color selMaxColor)
     {
@@ -112,8 +79,8 @@ public abstract class ContactMapRenderer implements AnnotationRowRendererI
       {
         return new Shading(Color.pink, Color.red,
 
-                new Color(247, 252, 245), new Color(0, 68, 28),
-                new Color(28, 0, 68), new Color(245, 247, 252));
+                new Color(246, 252, 243), new Color(0, 60, 26),
+                new Color(26, 0, 60), new Color(243, 246, 252));
       }
     };
   }
@@ -135,7 +102,7 @@ public abstract class ContactMapRenderer implements AnnotationRowRendererI
           HiddenColumns hiddenColumns, ColumnSelection columnSelection,
           AlignmentAnnotation _aa, Annotation[] aa_annotations, int sRes,
           int eRes, float min, float max, int y)
-  {
+  {    
     if (sRes > aa_annotations.length)
     {
       return;
@@ -146,17 +113,12 @@ public abstract class ContactMapRenderer implements AnnotationRowRendererI
 
     // uncomment below to render whole area of matrix as pink
     // g.setColor(shade.no_data);
-    // g.fillRect(x, topY-_aa.height, (eRes - sRes) * charWidth,
-    // _aa.graphHeight);
-
+    // g.fillRect(x, topY-_aa.height, (eRes - sRes) * charWidth, _aa.graphHeight);
+    
     boolean showGroups = _aa.isShowGroupsForContactMatrix();
     int column;
     int aaMax = aa_annotations.length - 1;
     ContactMatrixI cm = viewport.getContactMatrix(_aa);
-    if (cm == null)
-    {
-      return;
-    }
     while (x < eRes - sRes)
     {
       column = sRes + x;
@@ -207,14 +169,14 @@ public abstract class ContactMapRenderer implements AnnotationRowRendererI
       for (int ht = 0, botY = topY
               - _aa.height; ht < _aa.graphHeight; ht += cgeom.pixels_step)
       {
-        ContactGeometry.contactInterval ci = cgeom.mapFor(ht);
+        ContactGeometry.contactInterval ci = cgeom.mapFor(ht,
+                ht + cgeom.pixels_step);
         // cstart = (int) Math.floor(((double) y2 - ht) * contacts_per_pixel);
         // cend = (int) Math.min(contact_height,
         // Math.ceil(cstart + contacts_per_pixel * pixels_step));
 
         Color col;
-        boolean rowsel = false;
-        boolean containsHidden = false;
+        boolean rowsel = false, containsHidden = false;
         if (columnSelection != null)
         {
           rowsel = cgeom.intersects(ci, columnSelection, hiddenColumns,
@@ -246,20 +208,20 @@ public abstract class ContactMapRenderer implements AnnotationRowRendererI
         if (showGroups && gpcol != null && gpcol != Color.white)
         {
           // todo - could overlay group as a transparent rectangle ?
-          col = new Color((int) ((col.getRed() + gpcol.getRed()) / 2f),
-                  (int) ((col.getGreen() + gpcol.getGreen()) / 2f),
-                  (int) ((col.getBlue() + gpcol.getBlue()) / 2f));
+          col = new Color(
+                  (int) (((float) (col.getRed() + gpcol.getRed())) / 2f),
+                  (int) (((float) (col.getGreen() + gpcol.getGreen()))
+                          / 2f),
+                  (int) (((float) (col.getBlue() + gpcol.getBlue())) / 2f));
         }
         g.setColor(col);
         if (cgeom.pixels_step > 1)
         {
-          g.fillRect(x * charWidth, botY + ht, charWidth,
-                  cgeom.pixels_step);
+          g.fillRect(x * charWidth, botY+ht, charWidth, 1 + cgeom.pixels_step);
         }
         else
         {
-          g.drawLine(x * charWidth, botY + ht, (x + 1) * charWidth,
-                  botY + ht);
+          g.drawLine(x * charWidth, botY+ht, (x + 1) * charWidth, botY+ht);
         }
       }
       x++;
@@ -286,7 +248,7 @@ public abstract class ContactMapRenderer implements AnnotationRowRendererI
   {
     ContactRange cr = cl.getRangeFor(i, j);
     // average for moment - probably more interested in maxIntProj though
-    return jalview.util.ColorUtils.getGraduatedColour((float) cr.getMin(),
+    return jalview.util.ColorUtils.getGraduatedColour((float) cr.getMean(),
             0, shade.selMinColor, max, shade.selMaxColor);
   }
 
