@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -309,7 +309,7 @@ public class Platform
       time = mark = t;
       if (msg != null)
       {
-        jalview.bin.Console.errPrintln("Platform: timer reset\t\t\t" + msg);
+        System.err.println("Platform: timer reset\t\t\t" + msg);
       }
       break;
     case TIME_MARK:
@@ -325,9 +325,8 @@ public class Platform
         }
         if (msg != null)
         {
-          jalview.bin.Console.errPrintln(
-                  "Platform: timer mark\t" + ((t - time) / 1000f) + "\t"
-                          + ((t - mark) / 1000f) + "\t" + msg);
+          System.err.println("Platform: timer mark\t" + ((t - time) / 1000f)
+                  + "\t" + ((t - mark) / 1000f) + "\t" + msg);
         }
         mark = t;
       }
@@ -338,9 +337,8 @@ public class Platform
     case TIME_GET:
       if (msg != null)
       {
-        jalview.bin.Console
-                .errPrintln("Platform: timer dur\t" + ((t - time) / 1000f)
-                        + "\t" + ((duration) / 1000f) + "\t" + msg);
+        System.err.println("Platform: timer dur\t" + ((t - time) / 1000f)
+                + "\t" + ((duration) / 1000f) + "\t" + msg);
       }
       set = 0;
       break;
@@ -496,7 +494,7 @@ public class Platform
      *            info[key];
      */
 
-    jalview.bin.Console.outPrintln(
+    System.out.println(
             "Platform id=" + id + " reading Info." + key + " = " + value);
     p.put(id + "_" + key, value);
 
@@ -622,7 +620,7 @@ public class Platform
 
     if (isJS())
     {
-      jalview.bin.Console.outPrintln(
+      System.out.println(
               "Platform adding known access-control-allow-origin * for domain "
                       + domain);
       /**
@@ -646,13 +644,12 @@ public class Platform
        * @j2sNative var a =
        *            decodeURI((document.location.href.replace("&","?").split("?j2s")[0]
        *            + "?").split("?")[1].split("#")[0]); a &&
-       *            (jalview.bin.Console.outPrintln("URL arguments detected were
-       *            "+a)) && (J2S.thisApplet.__Info.urlargs = a.split(" "));
+       *            (System.out.println("URL arguments detected were "+a)) &&
+       *            (J2S.thisApplet.__Info.urlargs = a.split(" "));
        *            (!J2S.thisApplet.__Info.args || J2S.thisApplet.__Info.args
        *            == "" || J2S.thisApplet.__Info.args == "??") &&
-       *            (J2S.thisApplet.__Info.args = a) &&
-       *            (jalview.bin.Console.outPrintln("URL arguments were passed
-       *            to J2S main."));
+       *            (J2S.thisApplet.__Info.args = a) && (System.out.println("URL
+       *            arguments were passed to J2S main."));
        */
     } catch (Throwable t)
     {
