@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -20,6 +20,10 @@
  */
 package jalview.workers;
 
+import jalview.api.AlignCalcManagerI;
+import jalview.api.AlignCalcWorkerI;
+import jalview.datamodel.AlignmentAnnotation;
+
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -29,10 +33,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
-import jalview.api.AlignCalcManagerI;
-import jalview.api.AlignCalcWorkerI;
-import jalview.datamodel.AlignmentAnnotation;
-
 public class AlignCalcManager implements AlignCalcManagerI
 {
   /*
@@ -145,8 +145,7 @@ public class AlignCalcManager implements AlignCalcManagerI
   {
     synchronized (inProgress)
     {
-      // jalview.bin.Console.errPrintln("Worker " + worker + " marked as
-      // complete.");
+      // System.err.println("Worker " + worker + " marked as complete.");
       inProgress.remove(worker);
       List<AlignCalcWorkerI> upd = updating.get(worker.getClass());
       if (upd != null)
@@ -193,7 +192,7 @@ public class AlignCalcManager implements AlignCalcManagerI
   public boolean isWorking(AlignCalcWorkerI worker)
   {
     synchronized (inProgress)
-    {// jalview.bin.Console.errPrintln("isWorking : worker "+(worker!=null ?
+    {// System.err.println("isWorking : worker "+(worker!=null ?
      // worker.getClass():"null")+ " "+hashCode());
       return worker != null && inProgress.contains(worker);
     }
@@ -202,10 +201,10 @@ public class AlignCalcManager implements AlignCalcManagerI
   @Override
   public boolean isWorking()
   {
-    boolean working = false;
+    boolean working=false;
     synchronized (inProgress)
     {
-      // jalview.bin.Console.errPrintln("isWorking "+hashCode());
+      // System.err.println("isWorking "+hashCode());
       working |= inProgress.size() > 0;
     }
     synchronized (updating)
@@ -215,10 +214,9 @@ public class AlignCalcManager implements AlignCalcManagerI
       {
         for (List<AlignCalcWorkerI> workers : workersLists)
         {
-          if (workers != null)
+          if (workers!=null)
           {
-            synchronized (workers)
-            {
+            synchronized (workers) {
               working |= workers.size() > 0;
             }
           }
@@ -307,16 +305,14 @@ public class AlignCalcManager implements AlignCalcManagerI
           Class<? extends AlignCalcWorkerI> workerClass)
   {
     List<AlignCalcWorkerI> workingClass = new ArrayList<AlignCalcWorkerI>();
-    AlignCalcWorkerI[] workers;
     synchronized (canUpdate)
     {
-      workers = canUpdate.toArray(new AlignCalcWorkerI[0]);
-    }
-    for (AlignCalcWorkerI worker : workers)
-    {
-      if (workerClass.equals(worker.getClass()))
+      for (AlignCalcWorkerI worker : canUpdate)
       {
-        workingClass.add(worker);
+        if (workerClass.equals(worker.getClass()))
+        {
+          workingClass.add(worker);
+        }
       }
     }
     return (workingClass.size() == 0) ? null : workingClass;
@@ -371,7 +367,7 @@ public class AlignCalcManager implements AlignCalcManagerI
      * {
      * 
      * if (isPending(worker)) { worker.abortAndDestroy(); startWorker(worker); }
-     * else { jalview.bin.Console.errPrintln("Pending exists for " + workerClass); } }
+     * else { System.err.println("Pending exists for " + workerClass); } }
      */
   }
 
