@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -29,6 +29,7 @@ import java.util.HashMap;
 import java.util.Hashtable;
 import java.util.List;
 import java.util.Map;
+import java.util.StringTokenizer;
 import java.util.Vector;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -75,7 +76,7 @@ public class DBRefFetcher implements Runnable
 
   IProgressIndicator progressWindow;
 
-  CutAndPasteTransfer output;
+  CutAndPasteTransfer output = new CutAndPasteTransfer();
 
   /**
    * picr client instance
@@ -301,8 +302,7 @@ public class DBRefFetcher implements Runnable
       }
     } catch (Exception e)
     {
-      jalview.bin.Console
-              .errPrintln("Couldn't locate PICR service instance.\n");
+      System.err.println("Couldn't locate PICR service instance.\n");
       e.printStackTrace();
     }
 
@@ -316,8 +316,7 @@ public class DBRefFetcher implements Runnable
     while (sdataset.size() > 0 && db < dbSources.length)
     {
       int maxqlen = 1; // default number of queries made at one time
-      jalview.bin.Console
-              .outPrintln("Verifying against " + dbSources[db].getDbName());
+      System.out.println("Verifying against " + dbSources[db].getDbName());
 
       // iterate through db for each remaining un-verified sequence
       SequenceI[] currSeqs = new SequenceI[sdataset.size()];
@@ -426,7 +425,7 @@ public class DBRefFetcher implements Runnable
                             true);
                   } catch (Exception e)
                   {
-                    jalview.bin.Console.errPrintln(
+                    System.err.println(
                             "Exception with Picr for '" + token + "'\n");
                     e.printStackTrace();
                   }
@@ -439,7 +438,7 @@ public class DBRefFetcher implements Runnable
                     // present, and do a transferReferences
                     // otherwise transfer non sequence x-references directly.
                   }
-                  jalview.bin.Console.outPrintln(
+                  System.out.println(
                           "Validated ID against PICR... (for what its worth):"
                                   + token);
                   addSeqId(sequence, token);
@@ -448,7 +447,7 @@ public class DBRefFetcher implements Runnable
                 else
                 {
                   // if ()
-                  // jalview.bin.Console.outPrintln("Not querying source with
+                  // System.out.println("Not querying source with
                   // token="+token+"\n");
                   addSeqId(sequence, token);
                   queries.addElement(token.toUpperCase(Locale.ROOT));
@@ -470,7 +469,6 @@ public class DBRefFetcher implements Runnable
       {
         sb.append(msg).append(NEWLINE);
       }
-      output = new CutAndPasteTransfer();
       output.setText(sb.toString());
 
       Desktop.addInternalFrame(output,
@@ -514,7 +512,7 @@ public class DBRefFetcher implements Runnable
           DbSourceProxy dbSourceProxy, AlignmentI retrievedAl,
           boolean trimDatasetSeqs, List<String> warningMessages)
   {
-    // jalview.bin.Console.outPrintln("trimming ? " + trimDatasetSeqs);
+    // System.out.println("trimming ? " + trimDatasetSeqs);
     if (retrievedAl == null || retrievedAl.getHeight() == 0)
     {
       return false;
@@ -680,8 +678,8 @@ public class DBRefFetcher implements Runnable
           }
         }
 
-        jalview.bin.Console.outPrintln("Adding dbrefs to "
-                + sequence.getName() + " from " + dbSource + " sequence : "
+        System.out.println("Adding dbrefs to " + sequence.getName()
+                + " from " + dbSource + " sequence : "
                 + retrievedSeq.getName());
         sequence.transferAnnotation(retrievedSeq, mp);
 
