@@ -1,23 +1,3 @@
-/*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
- * 
- * This file is part of Jalview.
- * 
- * Jalview is free software: you can redistribute it and/or
- * modify it under the terms of the GNU General Public License 
- * as published by the Free Software Foundation, either version 3
- * of the License, or (at your option) any later version.
- *  
- * Jalview is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty 
- * of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
- * PURPOSE.  See the GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with Jalview.  If not, see <http://www.gnu.org/licenses/>.
- * The Jalview Authors are detailed in the 'AUTHORS' file.
- */
 package jalview.ws.datamodel.alphafold;
 
 import java.awt.Color;
@@ -27,7 +7,6 @@ import java.util.BitSet;
 import jalview.datamodel.ContactListI;
 import jalview.datamodel.ContactListImpl;
 import jalview.datamodel.ContactListProviderI;
-import jalview.datamodel.ContactMatrixI;
 import jalview.datamodel.GroupSet;
 import jalview.datamodel.GroupSetI;
 import jalview.datamodel.Mapping;
@@ -38,58 +17,6 @@ import jalview.ws.datamodel.MappableContactMatrixI;
 public abstract class MappableContactMatrix<T extends MappableContactMatrix<T>>
         implements MappableContactMatrixI
 {
-  /**
-   * the matrix that is being mapped to
-   */
-  protected ContactMatrixI mappedMatrix = null;
-
-  public ContactListI getContactList(int column)
-  {
-    return mappedMatrix.getContactList(column);
-  }
-
-  public float getMin()
-  {
-    return mappedMatrix.getMin();
-  }
-
-  public float getMax()
-  {
-    return mappedMatrix.getMax();
-  }
-
-  public int getWidth()
-  {
-    return mappedMatrix.getWidth();
-  }
-
-  public int getHeight()
-  {
-    return mappedMatrix.getHeight();
-  }
-
-  @Override
-  public ContactMatrixI getMappedMatrix()
-  {
-    return mappedMatrix;
-  }
-
-  @Override
-  public GroupSetI getGroupSet()
-  {
-    return mappedMatrix.getGroupSet();
-  };
-
-  @Override
-  public void setGroupSet(GroupSet makeGroups)
-  {
-    mappedMatrix.setGroupSet(makeGroups);
-  }
-
-  /**
-   * the sequence and how it is mapped to the matrix
-   */
-
   SequenceI refSeq = null;
 
   MapList toSeq = null;
@@ -111,6 +38,23 @@ public abstract class MappableContactMatrix<T extends MappableContactMatrix<T>>
     return refSeq;
   }
 
+  /**
+   * container for groups - defined on matrix columns
+   */
+  GroupSet grps = new GroupSet();
+
+  @Override
+  public GroupSetI getGroupSet()
+  {
+    return grps;
+  };
+
+  @Override
+  public void setGroupSet(GroupSet makeGroups)
+  {
+    grps = makeGroups;
+  }
+
   @Override
   public MapList getMapFor(SequenceI mapSeq)
   {
@@ -274,9 +218,9 @@ public abstract class MappableContactMatrix<T extends MappableContactMatrix<T>>
               + "' is not mappable for the given localFrame sequence. ("
               + localFrame.getName() + ")");
     }
-
+    
     // now look up from-to matrix columns in toSeq frame
-
+    
     if (toSeq == null)
     {
       // no mapping - so we assume 1:1
@@ -286,33 +230,33 @@ public abstract class MappableContactMatrix<T extends MappableContactMatrix<T>>
     // first locate on reference sequence
 
     int[] mappedPositions = toSeq.locateInFrom(from, to);
-    if (mappedPositions == null)
+    if (mappedPositions==null)
     {
       return null;
     }
-
+    
     // and now map to localFrame
     // from-to columns on the associated sequence should be
     // i. restricted to positions in localFrame
-    // ii.
+    // ii. 
 
-    // int s = -1, e = -1;
-    // for (int p = 0; p < mappedPositions.length; p++)
-    // {
-    // if (s == -1 && mappedPositions[p] >= localFrame.getStart())
-    // {
-    // s = p; // remember first position within local frame
-    // }
-    // if (e == -1 || mappedPositions[p] <= localFrame.getEnd())
-    // {
-    // // update end pointer
-    // e = p;
-    // // compute local map
-    // mappedPositions[p] = localFrame.findIndex(mappedPositions[p]);
-    // }
-    // }
-    // int[] _trimmed = new int[e - s + 1];
-    // return _trimmed;
+//    int s = -1, e = -1;
+//    for (int p = 0; p < mappedPositions.length; p++)
+//    {
+//      if (s == -1 && mappedPositions[p] >= localFrame.getStart())
+//      {
+//        s = p; // remember first position within local frame
+//      }
+//      if (e == -1 || mappedPositions[p] <= localFrame.getEnd())
+//      {
+//        // update end pointer
+//        e = p;
+//        // compute local map
+//        mappedPositions[p] = localFrame.findIndex(mappedPositions[p]);
+//      }
+//    }
+//    int[] _trimmed = new int[e - s + 1];
+//    return _trimmed;
     return mappedPositions;
   }
 
@@ -495,38 +439,14 @@ public abstract class MappableContactMatrix<T extends MappableContactMatrix<T>>
   }
 
   /**
-   * get a specific element of the underlying contact matrix in its data-local
-   * coordinates rather than the mapped frame. Implementations are allowed to
-   * throw RunTimeExceptions if _column/i are out of bounds
+   * get a specific element of the contact matrix in its data-local coordinates
+   * rather than the mapped frame. Implementations are allowed to throw
+   * RunTimeExceptions if _column/i are out of bounds
    * 
    * @param _column
    * @param i
    * @return
    */
-  public double getElementAt(int _column, int i)
-  {
-    return mappedMatrix.getElementAt(_column, i);
-  }
+  protected abstract double getElementAt(int _column, int i);
 
-  @Override
-  public int hashCode()
-  {
-    return 7 * (refSeq != null ? refSeq.hashCode() : 0)
-            + 11 * (toSeq != null ? toSeq.hashCode() : 0)
-            + 13 * (mappedMatrix != null ? mappedMatrix.hashCode() : 0)
-            + length * 3;
-  }
-
-  @Override
-  public boolean equals(Object obj)
-  {
-    if (obj == null || !(obj.getClass().equals(getClass())))
-    {
-      return false;
-    }
-    T them = (T) obj;
-    return mappedMatrix == them.mappedMatrix && length == them.length
-            && refSeq == them.refSeq && toSeq.equals(them.toSeq);
-
-  }
 }
