@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -23,6 +23,10 @@
  */
 package jalview.ws.jws2;
 
+import jalview.bin.Console;
+import jalview.ws.jws2.jabaws2.Jws2Instance;
+import jalview.ws.jws2.jabaws2.Jws2InstanceFactory;
+
 import java.io.IOException;
 import java.net.MalformedURLException;
 import java.net.URL;
@@ -33,10 +37,6 @@ import compbio.data.msa.Category;
 import compbio.data.msa.JABAService;
 import compbio.ws.client.Jws2Client;
 import compbio.ws.client.Services;
-import jalview.bin.Console;
-import jalview.util.HttpUtils;
-import jalview.ws.jws2.jabaws2.Jws2Instance;
-import jalview.ws.jws2.jabaws2.Jws2InstanceFactory;
 
 /**
  * @author JimP
@@ -117,7 +117,7 @@ public class JabaWsServerQuery implements Runnable
           registry = Jws2Client.connectToRegistry(jwsserver);
           if (registry != null)
           {
-            // jalview.bin.Console.errPrintln("Test Services Output\n"
+            // System.err.println("Test Services Output\n"
             // + registry.testAllServices());
             // TODO: enumerate services and test those that haven't been tested
             // in the last n-days/hours/etc.
@@ -126,25 +126,23 @@ public class JabaWsServerQuery implements Runnable
             srv_set = registry.getSupportedServices();
 
             // dan test
-            jalview.bin.Console.outPrintln(
+            System.out.println(
                     "registry.getSupportedServices: " + srv_set.toString());
 
             svccategories = registry.getServiceCategories();
 
             // dan test
-            // jalview.bin.Console.outPrintln("registry.getServiceCategories: "
-            // +
+            // System.out.println("registry.getServiceCategories: " +
             // svccategories.toString());
 
           }
         } catch (Exception ex)
         {
-          jalview.bin.Console.errPrintln(
-                  "Exception whilst trying to get at registry:");
+          System.err.println("Exception whilst trying to get at registry:");
           ex.printStackTrace();
           // if that failed, then we are probably working with a JABAWS1 server.
           // in that case, look for each service endpoint
-          jalview.bin.Console.errPrintln("JWS2 Discoverer: " + jwsserver
+          System.err.println("JWS2 Discoverer: " + jwsserver
                   + " is a JABAWS1 server. Using hardwired list.");
           for (Services srv : JABAWS1SERVERS)
           {
@@ -171,9 +169,8 @@ public class JabaWsServerQuery implements Runnable
               service = Jws2Client.connect(jwsserver, srv);
             } catch (Exception e)
             {
-              jalview.bin.Console.errPrintln("Jws2 Discoverer: Problem on "
-                      + jwsserver + " with service " + srv + ":\n"
-                      + e.getMessage());
+              System.err.println("Jws2 Discoverer: Problem on " + jwsserver
+                      + " with service " + srv + ":\n" + e.getMessage());
               if (!(e instanceof javax.xml.ws.WebServiceException))
               {
                 e.printStackTrace();
@@ -244,16 +241,16 @@ public class JabaWsServerQuery implements Runnable
       try
       {
         URL url = new URL(server);
-        HttpUtils.openStream(url).close();
+        url.openStream().close();
         result = true;
       } catch (MalformedURLException e)
       {
-        jalview.bin.Console.errPrintln("Invalid server URL: " + server);
+        System.err.println("Invalid server URL: " + server);
         result = false;
       } catch (IOException e)
       {
-        jalview.bin.Console.errPrintln("Error connecting to server: "
-                + server + ": " + e.toString());
+        System.err.println("Error connecting to server: " + server + ": "
+                + e.toString());
         result = false;
       }
     }
