@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -326,10 +326,7 @@ public class EnsemblGeneTest
     assertTrue(geneIds.contains("ENSRNOG00000010957")); // rat
     assertTrue(geneIds.contains("ENSXETG00000004845")); // xenopus
     assertTrue(geneIds.contains("ENSDARG00000017661")); // zebrafish
-    // was ENSGALG00000012865 - which is still the canonical uniprot BRAF cross
-    // reference via GRCg6a
-    assertTrue(geneIds.contains("ENSGALG00010013466")); // chicken BRAF
-                                                        // bGalGal1.mat.broiler.GRCg7b
+    assertTrue(geneIds.contains("ENSGALG00000012865")); // chicken
     assertEquals(8, geneIds.size());
 
   }
