@@ -1,6 +1,6 @@
 /*
- * Jalview - A Sequence Alignment Editor and Viewer (2.11.4.0)
- * Copyright (C) 2024 The Jalview Authors
+ * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
+ * Copyright (C) $$Year-Rel$$ The Jalview Authors
  * 
  * This file is part of Jalview.
  * 
@@ -199,7 +199,7 @@ public class AnnotatedPDBFileInputTest
   {
     jalview.bin.Jalview
             .main(new String[]
-            { "--props", "test/jalview/io/testProps.jvprops" });
+            { "-props", "test/jalview/io/testProps.jvprops" });
   }
 
   /**
