@@ -1,12 +1,13 @@
 #!/usr/bin/env bash
 
 # perform a dev build and install on local macOS machine
-INSTALLERVOL="Jalview Installer"
-APP=Jalview.app
+INSTALLERVOL="Jalview Non-Release Installer"
+APP="Jalview Local.app"
 
-APPLICATIONS=$HOME/Applications
+APPLICATIONS=/Applications
 CHANNEL=NOCHANNEL
-DMG=build/install4j/11/Jalview-OFFLINE_macos-app_DEVELOPMENT-j11.dmg
+DMG=build/install4j/11/Jalview_Local-TEST-macos-java_11.dmg
+
 
 if [ x$1 != "xnogradle" ]; then
   gradle installers -PCHANNEL=LOCAL -Pinstall4j_media_types=macosArchive
@@ -33,7 +34,10 @@ if [ $? = 0 ]; then
   echo ""
 fi
 if [ -e "/Volumes/$INSTALLERVOL/$APP" ]; then
+  echo "Removing '$APPLICATIONS/$APP'"
   /bin/rm -r "$APPLICATIONS/$APP"
+  echo "Syncing '/Volumes/$INSTALLERVOL/$APP' to '$APPLICATIONS/'"
   rsync -avh "/Volumes/$INSTALLERVOL/$APP" "$APPLICATIONS/"
+  echo "Unmounting '/Volumes/$INSTALLERVOL'"
   umount "/Volumes/$INSTALLERVOL"
 fi
